@@ -706,6 +706,7 @@ void setup_icon_size_limits(FvwmWindow *fw, window_style *pstyle)
 		fw->min_icon_height = SGET_MIN_ICON_HEIGHT(*pstyle);
 		fw->max_icon_width = SGET_MAX_ICON_WIDTH(*pstyle);
 		fw->max_icon_height = SGET_MAX_ICON_HEIGHT(*pstyle);
+		fw->icon_resize_type = SGET_ICON_RESIZE_TYPE(*pstyle);
 	}
 	else
 	{
@@ -713,11 +714,49 @@ void setup_icon_size_limits(FvwmWindow *fw, window_style *pstyle)
 		fw->min_icon_height = MIN_ALLOWABLE_ICON_DIMENSION;
 		fw->max_icon_width = MAX_ALLOWABLE_ICON_DIMENSION;
 		fw->max_icon_height = MAX_ALLOWABLE_ICON_DIMENSION;
+		fw->icon_resize_type = ICON_RESIZE_TYPE_NONE;
 	}
 
 	return;
 }
 
+void setup_icon_background_parameters(FvwmWindow *fw, window_style *pstyle)
+{
+	if (SHAS_ICON_BACKGROUND_PADDING(&pstyle->flags))
+	{
+		fw->icon_background_padding =
+			SGET_ICON_BACKGROUND_PADDING(*pstyle);
+	}
+	else
+	{
+		fw->icon_background_padding = ICON_BACKGROUND_PADDING;
+	}
+	if (SHAS_ICON_BACKGROUND_RELIEF(&pstyle->flags))
+	{
+		fw->icon_background_relief =
+			SGET_ICON_BACKGROUND_RELIEF(*pstyle);
+	}
+	else
+	{
+		fw->icon_background_relief = ICON_RELIEF_WIDTH;
+	}
+	return;
+}
+
+void setup_icon_title_parameters(FvwmWindow *fw, window_style *pstyle)
+{
+	if (SHAS_ICON_TITLE_RELIEF(&pstyle->flags))
+	{
+		fw->icon_title_relief =
+			SGET_ICON_TITLE_RELIEF(*pstyle);
+	}
+	else
+	{
+		fw->icon_title_relief = ICON_RELIEF_WIDTH;
+	}
+	return;
+}
+
 static void setup_frame_window(
 	FvwmWindow *fw)
 {
@@ -1713,7 +1752,7 @@ void setup_icon_font(
 		resize_icon_title_height(fw, height - fw->icon_font->height);
 		/* this repositions the icon even if the window is not
 		 * iconified */
-		DrawIconWindow(fw, True, True, False, NULL);
+		DrawIconWindow(fw, True, True, False, False, NULL);
 	}
 
 	return;
@@ -1794,6 +1833,15 @@ void setup_style_and_decor(
 	update_window_color_style(fw, pstyle);
 	update_window_color_hi_style(fw, pstyle);
 
+	/***** icons colorsets *****/
+	update_icon_title_cs_style(fw, pstyle);
+	update_icon_title_cs_hi_style(fw, pstyle);
+	update_icon_background_cs_style(fw, pstyle);
+
+	/***** icons title/background parameters ****/
+	setup_icon_background_parameters(fw, pstyle);
+	setup_icon_title_parameters(fw, pstyle);
+
 	/****** window shading ******/
 	fw->shade_anim_steps = pstyle->shade_anim_steps;
 
@@ -1998,6 +2046,7 @@ void setup_focus_policy(FvwmWindow *fw)
 Bool validate_transientfor(FvwmWindow *fw)
 {
 	XWindowAttributes wa;
+	FvwmWindow *cw;
 	Window w;
 
 	w = FW_W_TRANSIENTFOR(fw);
@@ -2006,6 +2055,15 @@ Bool validate_transientfor(FvwmWindow *fw)
 		FW_W_TRANSIENTFOR(fw) = Scr.Root;
 		return False;
 	}
+	else if (XFindContext(dpy, w, FvwmContext, (caddr_t *)&cw) != XCNOENT)
+	{
+		if (cw == fw)
+		{
+			/* It's a transient of itself, ignore the hint */
+			FW_W_TRANSIENTFOR(fw) = Scr.Root;
+			return False;
+		}
+	}
 	else if (!XGetWindowAttributes(dpy, w, &wa) ||
 		 wa.map_state != IsViewable)
 	{
@@ -2338,8 +2396,8 @@ FvwmWindow *AddWindow(
 		int stick_page;
 		int stick_desk;
 
-		stick_page = is_window_sticky_on_page(fw);
-		stick_desk = is_window_sticky_on_page(fw);
+		stick_page = is_window_sticky_across_pages(fw);
+		stick_desk = is_window_sticky_across_pages(fw);
 		if ((stick_page &&
 		     !IsRectangleOnThisPage(&fw->frame_g, Scr.CurrentDesk)) ||
 		    (stick_desk && fw->Desk != Scr.CurrentDesk))
@@ -2355,8 +2413,8 @@ FvwmWindow *AddWindow(
 			ecc.w.wcontext = C_FRAME;
 			exc2 = exc_clone_context(
 				exc, &ecc, ECC_FW | ECC_W | ECC_WCONTEXT);
-			SET_STICKY_ON_PAGE(fw, 0);
-			SET_STICKY_ON_DESK(fw, 0);
+			SET_STICKY_ACROSS_PAGES(fw, 0);
+			SET_STICKY_ACROSS_DESKS(fw, 0);
 			handle_stick(
 				NULL, exc2, "", stick_page, stick_desk, 1, 0);
 			exc_destroy_context(exc2);
@@ -2756,8 +2814,16 @@ void GetWindowSizeHints(FvwmWindow *tmp)
 			}
 			tmp->hints.flags &= ~PAspect;
 			fvwm_msg(
-				WARN, "GetWindowSizeHints", "%s window %#lx"
-				" has broken aspect ratio: %d/%d - %d/%d\n",
+				WARN, "GetWindowSizeHints",
+				"The applicaton window \"%s\"\n"
+				"(window id %#lx)"
+				" has broken aspect ratio: %d/%d - %d/%d\n"
+				"Fvwm is ignoring the aspect ratio.  "
+				"If you are having a problem\n"
+				"with the application, send this message to"
+				" the application owner.\n"
+				"There is no need to notify "
+				"fvwm-workers@fvwm.org.\n",
 				tmp->name.name, FW_W(tmp), minAspectX,
 				minAspectY, maxAspectX, maxAspectY);
 		}
@@ -2802,10 +2868,14 @@ void GetWindowSizeHints(FvwmWindow *tmp)
 	if (*broken_cause != 0)
 	{
 		fvwm_msg(WARN, "GetWindowSizeHints",
-			 "%s window %#lx has broken (%s) size hints\n"
-			 "Please send a bug report to the application owner,\n"
-			 "\tyou may use fvwm-workers@fvwm.org as a reference.\n"
-			 "hint override = %d\n"
+			 "The application window \"%s\"\n(window id %#lx) "
+			 "has broken size hints (%s).\n"
+			 "Fvwm is ignoring those hints.  "
+			 "If you are having a problem\n"
+			 "with the application, send this message to"
+			 " the application owner.\n"
+			 "There is no need to notify fvwm-workers@fvwm.org.\n"
+			 "hint override = %d "
 			 "flags = %lx\n"
 			 "min_width = %d, min_height = %d, "
 			 "max_width = %d, max_height = %d\n"
