@@ -37,6 +37,8 @@ void setup_placement_penalty(FvwmWindow *fw, window_style *pstyle);
 void setup_focus_policy(FvwmWindow *fw);
 Bool setup_transientfor(FvwmWindow *fw);
 void setup_icon_size_limits(FvwmWindow *fw, window_style *pstyle);
+void setup_icon_background_parameters(FvwmWindow *fw, window_style *pstyle);
+void setup_icon_title_parameters(FvwmWindow *fw, window_style *pstyle);
 Bool validate_transientfor(FvwmWindow *fw);
 void setup_title_geometry(
 	FvwmWindow *fw, window_style *pstyle);
