@@ -25,8 +25,6 @@
 
 #include "config.h"
 
-#ifdef HAVE_EWMH
-
 #include <stdio.h>
 
 #include "libs/fvwmlib.h"
@@ -363,7 +361,7 @@ int check_desk(void)
 
   for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
   {
-    if (!IS_STICKY(t))
+    if (!IS_STICKY_ACROSS_DESKS(t))
       d = max(d,t->Desk);
   }
   return d;
@@ -430,7 +428,7 @@ void EWMH_SetWMDesktop(FvwmWindow *fwin)
 {
   CARD32 desk = fwin->Desk;
 
-  if (IS_STICKY(fwin))
+  if (IS_STICKY_ACROSS_DESKS(fwin))
   {
     desk = 0xFFFFFFFE;
   }
@@ -729,7 +727,7 @@ void ewmh_ComputeAndSetWorkArea(void)
 
   for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
   {
-    if (DO_EWMH_IGNORE_STRUT_HINTS(t) || !IS_STICKY(t))
+    if (DO_EWMH_IGNORE_STRUT_HINTS(t) || !IS_STICKY_ACROSS_PAGES(t))
       continue;
     left = max(left, t->strut.left);
     right = max(right, t->strut.right);
@@ -767,7 +765,7 @@ void ewmh_HandleDynamicWorkArea(void)
 
   for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
   {
-    if (DO_EWMH_IGNORE_STRUT_HINTS(t) || !IS_STICKY(t))
+    if (DO_EWMH_IGNORE_STRUT_HINTS(t) || !IS_STICKY_ACROSS_PAGES(t))
       continue;
     dyn_left = max(dyn_left, t->dyn_strut.left);
     dyn_right = max(dyn_right, t->dyn_strut.right);
@@ -997,9 +995,12 @@ int ewmh_HandleDesktop(EWMH_CMD_ARGS)
   style->flags.use_layer = 1;
   style->flag_mask.use_layer = 1;
 
-  S_SET_IS_STICKY(SCF(*style), 1);
-  S_SET_IS_STICKY(SCM(*style), 1);
-  S_SET_IS_STICKY(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 
   S_SET_IS_FIXED(SCF(*style), 1);
   S_SET_IS_FIXED(SCM(*style), 1);
@@ -1072,9 +1073,12 @@ int ewmh_HandleDock(EWMH_CMD_ARGS)
 {
   fwin->ewmh_window_type = EWMH_WINDOW_TYPE_DOCK_ID;
 
-  S_SET_IS_STICKY(SCF(*style), 1);
-  S_SET_IS_STICKY(SCM(*style), 1);
-  S_SET_IS_STICKY(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 
   S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
   S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
@@ -1093,9 +1097,12 @@ int ewmh_HandleMenu(EWMH_CMD_ARGS)
 {
   fwin->ewmh_window_type = EWMH_WINDOW_TYPE_MENU_ID;
 
-  S_SET_IS_STICKY(SCF(*style), 1);
-  S_SET_IS_STICKY(SCM(*style), 1);
-  S_SET_IS_STICKY(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 
   S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
   S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
@@ -1133,9 +1140,12 @@ int ewmh_HandleToolBar(EWMH_CMD_ARGS)
 {
   fwin->ewmh_window_type = EWMH_WINDOW_TYPE_TOOLBAR_ID;
 
-  S_SET_IS_STICKY(SCF(*style), 1);
-  S_SET_IS_STICKY(SCM(*style), 1);
-  S_SET_IS_STICKY(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 
   S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
   S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
@@ -1420,4 +1430,3 @@ void EWMH_DLOG(char *msg, ...)
 }
 #endif
 
-#endif /* HAVE_EWMH */
