@@ -17,8 +17,6 @@
 
 #include "config.h"
 
-#ifdef HAVE_EWMH
-
 #include <stdio.h>
 
 #include "libs/fvwmlib.h"
@@ -750,13 +748,11 @@ int EWMH_SetIconFromWMIcon(FvwmWindow *fwin, CARD32 *list, unsigned int size,
 		}
 		if (alpha)
 		{
-			GC my_gc = fvwmlib_XCreateGC(dpy, alpha, 0, 0);
 			na = CreateStretchPixmap(dpy, alpha, width, height,
 						 FRenderGetAlphaDepth(),
 						 wanted_w, wanted_h,
-						 my_gc);
+						 Scr.AlphaGC);
 			XFreePixmap(dpy, alpha);
-			XFreeGC(dpy, my_gc);
 			alpha = na;
 		}
 		width = wanted_w;
@@ -811,5 +807,3 @@ int EWMH_SetIconFromWMIcon(FvwmWindow *fwin, CARD32 *list, unsigned int size,
 		free(list);
 	return 1;
 }
-
-#endif /* HAVE_EWMH */
