@@ -33,6 +33,7 @@
 #include "virtual.h"
 #include "colorset.h"
 #include "schedule.h"
+#include "libs/FGettext.h"
 
 /* ---------------------------- local definitions --------------------------- */
 
@@ -57,15 +58,24 @@ static char *function_vars[] =
 	"hilight.cs",
 	"shadow.cs",
 	"fgsh.cs",
+	"gt.",
 	"desk.name",
+	"desk.n",
 	"desk.width",
 	"desk.height",
+	"desk.pagesx",
+	"desk.pagesy",
 	"vp.x",
 	"vp.y",
 	"vp.width",
 	"vp.height",
 	"page.nx",
 	"page.ny",
+	"w.id",
+	"w.name",
+	"w.iconname",
+	"w.class",
+	"w.resource",
 	"w.x",
 	"w.y",
 	"w.width",
@@ -96,6 +106,9 @@ static char *function_vars[] =
 	"pointer.wy",
 	"pointer.cx",
 	"pointer.cy",
+	"version.num",
+	"version.info",
+	"version.line",
 	NULL
 };
 
@@ -106,15 +119,24 @@ enum
 	VAR_HILIGHT_CS,
 	VAR_SHADOW_CS,
 	VAR_FGSH_CS,
+	VAR_GT,
 	VAR_DESK_NAME,
+	VAR_DESK_N,
 	VAR_DESK_WIDTH,
 	VAR_DESK_HEIGHT,
+	VAR_DESK_PAGESX,
+	VAR_DESK_PAGESY,
 	VAR_VP_X,
 	VAR_VP_Y,
 	VAR_VP_WIDTH,
 	VAR_VP_HEIGHT,
 	VAR_PAGE_NX,
 	VAR_PAGE_NY,
+	VAR_W_ID,
+	VAR_W_NAME,
+	VAR_W_ICONNAME,
+	VAR_W_CLASS,
+	VAR_W_RESOURCE,
 	VAR_W_X,
 	VAR_W_Y,
 	VAR_W_WIDTH,
@@ -145,6 +167,9 @@ enum
 	VAR_POINTER_WY,
 	VAR_POINTER_CX,
 	VAR_POINTER_CY,
+	VAR_VERSION_NUM,
+	VAR_VERSION_INFO,
+	VAR_VERSION_LINE,
 } extended_vars;
 
 /* ---------------------------- exported variables (globals) ---------------- */
@@ -167,6 +192,7 @@ static int expand_vars_extended(
 	int y;
 	Pixel pixel = 0;
 	int val = -12345678;
+	const char *string = NULL;
 	Bool is_numeric = False;
 	Bool is_x;
 	Window context_w = Scr.Root;
@@ -217,6 +243,15 @@ static int expand_vars_extended(
 			break;
 		}
 		return pixel_to_color_string(dpy, Pcmap, pixel, target, False);
+	case VAR_GT:
+	{
+		if (rest == NULL)
+		{
+			return 0;
+		}
+		string = _(rest);
+		break;
+	}
 	case VAR_DESK_NAME:
 		if (sscanf(rest, "%d%n", &cs, &n) < 1)
 		{
@@ -230,8 +265,9 @@ static int expand_vars_extended(
 		s = GetDesktopName(cs);
 		if (s == NULL)
 		{
-			s = (char *)safemalloc(23 * sizeof(char));
-			sprintf(s, "Desk %i", cs);
+			const char *ddn = _("Desk");
+			s = (char *)safemalloc(19 + strlen(ddn));
+			sprintf(s, "%s %i", ddn, cs);
 			l = strlen(s);
 			if (output)
 			{
@@ -244,7 +280,7 @@ static int expand_vars_extended(
 			l = strlen(s);
 			if (output)
 			{
-				strcpy(output,s);
+				strcpy(output, s);
 			}
 		}
 		return l;
@@ -255,6 +291,10 @@ static int expand_vars_extended(
 	/* only exact matches for all other variables */
 	switch ((i = GetTokenIndex(var_name, function_vars, 0, &rest)))
 	{
+	case VAR_DESK_N:
+		is_numeric = True;
+		val = Scr.CurrentDesk;
+		break;
 	case VAR_DESK_WIDTH:
 		is_numeric = True;
 		val = Scr.VxMax + Scr.MyDisplayWidth;
@@ -263,6 +303,14 @@ static int expand_vars_extended(
 		is_numeric = True;
 		val = Scr.VyMax + Scr.MyDisplayHeight;
 		break;
+	case VAR_DESK_PAGESX:
+		is_numeric = True;
+		val = (int)(Scr.VxMax / Scr.MyDisplayWidth) + 1;
+		break;
+	case VAR_DESK_PAGESY:
+		is_numeric = True;
+		val = (int)(Scr.VyMax / Scr.MyDisplayHeight) + 1;
+		break;
 	case VAR_VP_X:
 		is_numeric = True;
 		val = Scr.Vx;
@@ -287,6 +335,37 @@ static int expand_vars_extended(
 		is_numeric = True;
 		val = (int)(Scr.Vy / Scr.MyDisplayHeight);
 		break;
+	case VAR_W_ID:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			sprintf(target, "0x%x", (unsigned int)FW_W(fw));
+			string = target;
+		}
+		break;
+	case VAR_W_NAME:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			string = fw->name.name;
+		}
+		break;
+	case VAR_W_ICONNAME:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			string = fw->icon_name.name;
+		}
+		break;
+	case VAR_W_CLASS:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			string = fw->class.res_class;
+		}
+		break;
+	case VAR_W_RESOURCE:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			string = fw->class.res_name;
+		}
+		break;
 	case VAR_W_X:
 	case VAR_W_Y:
 	case VAR_W_WIDTH:
@@ -539,6 +618,15 @@ static int expand_vars_extended(
 		}
 		val = (is_x) ? x : y;
 		break;
+	case VAR_VERSION_NUM:
+		string = VERSION;
+		break;
+	case VAR_VERSION_INFO:
+		string = VERSIONINFO;
+		break;
+	case VAR_VERSION_LINE:
+		string = Fvwm_VersionInfo;
+		break;
 	default:
 		/* unknown variable - try to find it in the environment */
 		s = getenv(var_name);
@@ -560,8 +648,14 @@ static int expand_vars_extended(
 		sprintf(target, "%d", val);
 		return strlen(target);
 	}
-
-	return 0;
+	else
+	{
+		if (output && string)
+		{
+			strcpy(output, string);
+		}
+		return string ? strlen(string) : 0;
+	}
 }
 
 /* ---------------------------- interface functions ------------------------- */
@@ -570,7 +664,7 @@ char *expand_vars(
 	char *input, char *arguments[], FvwmWindow *fw, Bool addto, Bool ismod,
 	fvwm_cond_func_rc *cond_rc)
 {
-	int l,i,l2,n,k,j,m;
+	int l, i, l2, n, k, j, m;
 	int xlen;
 	char *out;
 	char *var;
@@ -586,8 +680,8 @@ char *expand_vars(
 	}
 
 	/* Calculate best guess at length of expanded string */
-	i=0;
-	while (i<l)
+	i = 0;
+	while (i < l)
 	{
 		if (input[i] == '$' && (!ismod || !isalpha(input[i+1])))
 		{
@@ -821,6 +915,10 @@ char *expand_vars(
 			case 'w':
 				if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
 				{
+#if 0
+					fvwm_msg(OLD, "expand_vars",
+						"Use $[w.id] instead of $w");
+#endif
 					sprintf(&out[j], "0x%x",
 						(unsigned int)FW_W(fw));
 				}
@@ -832,16 +930,28 @@ char *expand_vars(
 				i++;
 				break;
 			case 'd':
+#if 0
+				fvwm_msg(OLD, "expand_vars",
+					"Use $[desk.n] instead of $d");
+#endif
 				sprintf(&out[j], "%d", Scr.CurrentDesk);
 				j += strlen(&out[j]);
 				i++;
 				break;
 			case 'x':
+#if 0
+				fvwm_msg(OLD, "expand_vars",
+					"Use $[vp.x] instead of $x");
+#endif
 				sprintf(&out[j], "%d", Scr.Vx);
 				j += strlen(&out[j]);
 				i++;
 				break;
 			case 'y':
+#if 0
+				fvwm_msg(OLD, "expand_vars",
+					"Use $[vp.y] instead of $y");
+#endif
 				sprintf(&out[j], "%d", Scr.Vy);
 				j += strlen(&out[j]);
 				i++;
@@ -855,6 +965,11 @@ char *expand_vars(
 					switch(input[i+1])
 					{
 					case 'c':
+#if 0
+						fvwm_msg(OLD, "expand_vars",
+							"Use $[w.class] "
+							"instead of $c");
+#endif
 						if (fw->class.res_class &&
 						    fw->class.res_class[0])
 						{
@@ -863,6 +978,11 @@ char *expand_vars(
 						}
 						break;
 					case 'r':
+#if 0
+						fvwm_msg(OLD, "expand_vars",
+							"Use $[w.resource] "
+							"instead of $r");
+#endif
 						if (fw->class.res_name &&
 						    fw->class.res_name[0])
 						{
@@ -871,6 +991,11 @@ char *expand_vars(
 						}
 						break;
 					case 'n':
+#if 0
+						fvwm_msg(OLD, "expand_vars",
+							"Use $[w.name] "
+							"instead of $n");
+#endif
 						if (fw->name.name &&
 						    fw->name.name[0])
 						{
@@ -882,6 +1007,8 @@ char *expand_vars(
 				is_string = True;
 				break;
 			case 'v':
+				fvwm_msg(OLD, "expand_vars",
+					"Use $[version.line] instead of $v");
 				sprintf(&out[j], "%s", (Fvwm_VersionInfo) ?
 					Fvwm_VersionInfo : "");
 				j += strlen(&out[j]);
