@@ -34,6 +34,7 @@
 #include "focus.h"
 #include "borders.h"
 #include "frame.h"
+extern void GetWindowSizeHints(FvwmWindow *tmp);
 
 /* ---------------------------- local definitions --------------------------- */
 
@@ -73,6 +74,7 @@ typedef struct
 	int current_step;
 	int curr_titlebar_compression;
 	direction_type shade_dir;
+	window_parts trans_parts;
 	struct
 	{
 		unsigned do_force : 1;
@@ -399,6 +401,8 @@ static void __frame_setup_window(
 	}
 	else if (is_moved)
 	{
+		unsigned int draw_parts = PART_NONE;
+
 		/* inform the application of the change
 		 *
 		 * According to the July 27, 1988 ICCCM draft, we should send a
@@ -406,6 +410,15 @@ static void __frame_setup_window(
 		 * was moved but not resized. */
 		XMoveWindow(dpy, FW_W_FRAME(fw), frame_g->x, frame_g->y);
 		fw->frame_g = *frame_g;
+		if ((draw_parts = border_get_transparent_decorations_part(fw))
+		    != PART_NONE)
+		{
+			border_draw_decorations(
+				fw, draw_parts,
+				((fw == get_focus_window())) ? True : False,
+				True, CLEAR_ALL, NULL, NULL);
+		}
+		fw->frame_g = *frame_g;
 		do_send_configure_notify = True;
 	}
 	/* must not send events to shaded windows because this might cause them
@@ -532,6 +545,7 @@ static void frame_set_decor_gravities(
 	int valuemask;
 	XSetWindowAttributes xcwa;
 	int i;
+	Bool button_reverted = False;
 
 	/* using bit gravity can reduce redrawing dramatically */
 	valuemask = CWWinGravity;
@@ -565,7 +579,19 @@ static void frame_set_decor_gravities(
 	}
 	xcwa.win_gravity = grav->title_grav;
 	XChangeWindowAttributes(dpy, FW_W_TITLE(fw), valuemask, &xcwa);
-	xcwa.win_gravity = grav->lbutton_grav;
+	if (fw->title_text_rotation == ROTATION_270 ||
+	    fw->title_text_rotation == ROTATION_180)
+	{
+		button_reverted = True;
+	}
+	if (button_reverted)
+	{
+		xcwa.win_gravity = grav->rbutton_grav;
+	}
+	else
+	{
+		xcwa.win_gravity = grav->lbutton_grav;
+	}
 	for (i = 0; i < NUMBER_OF_BUTTONS; i += 2)
 	{
 		if (FW_W_BUTTON(fw, i))
@@ -574,7 +600,14 @@ static void frame_set_decor_gravities(
 				dpy, FW_W_BUTTON(fw, i), valuemask, &xcwa);
 		}
 	}
-	xcwa.win_gravity = grav->rbutton_grav;
+	if (button_reverted)
+	{
+		xcwa.win_gravity = grav->lbutton_grav;
+	}
+	else
+	{
+		xcwa.win_gravity = grav->rbutton_grav;
+	}
 	for (i = 1; i < NUMBER_OF_BUTTONS; i += 2)
 	{
 		if (FW_W_BUTTON(fw, i))
@@ -587,6 +620,25 @@ static void frame_set_decor_gravities(
 	return;
 }
 
+/* Just restore the win and bit gravities on the client window. */
+static void frame_restore_client_gravities(FvwmWindow *fw)
+{
+	XSetWindowAttributes xcwa;
+	long valuemask;
+
+	valuemask = CWWinGravity;
+	if (fw->attr_backup.is_bit_gravity_stored)
+	{
+		fw->attr_backup.is_bit_gravity_stored = 0;
+		xcwa.bit_gravity = fw->attr_backup.bit_gravity;
+		valuemask = CWBitGravity;
+	}
+	xcwa.win_gravity = fw->hints.win_gravity;
+	XChangeWindowAttributes(dpy, FW_W(fw), valuemask, &xcwa);
+
+	return;
+}
+
 /* Prepares the structure for the next animation step. */
 static void frame_next_move_resize_args(
 	frame_move_resize_args mr_args)
@@ -1071,7 +1123,11 @@ static void frame_has_handles_and_tiled_border(
 	{
 		*ret_has_handles = 0;
 	}
-	*ret_has_tiled_border = (DFS_FACE_TYPE(df->style) == TiledPixmapButton);
+	*ret_has_tiled_border =
+		(DFS_FACE_TYPE(df->style) == TiledPixmapButton) ||
+		(DFS_FACE_TYPE(df->style) == ColorsetButton &&
+		 !CSET_IS_TRANSPARENT_PR(df->u.acs.cs) &&
+		 CSET_HAS_PIXMAP(df->u.acs.cs));
 
 	return;
 }
@@ -1213,6 +1269,7 @@ void frame_get_titlebar_dimensions(
 	int nbuttons_big;
 	int *padd_coord;
 	int *b_l;
+	Bool revert_button = False;
 
 	if (!HAS_TITLE(fw))
 	{
@@ -1309,10 +1366,17 @@ void frame_get_titlebar_dimensions(
 		tb_w = tb_length;
 		tb_h = tb_thick;
 	}
-	/* configure left buttons */
-	for (i = 0; i < NUMBER_OF_BUTTONS; i += 2)
+	if (fw->title_text_rotation == ROTATION_270 ||
+	    fw->title_text_rotation == ROTATION_180)
 	{
-		if (FW_W_BUTTON(fw, i) == None)
+		revert_button = True;
+	}
+
+	/* configure left buttons */
+	for (i = 0; i < NUMBER_OF_BUTTONS; i++)
+	{
+		if ((revert_button && !(i & 1)) || (!revert_button && (i & 1)) ||
+		    FW_W_BUTTON(fw, i) == None)
 		{
 			continue;
 		}
@@ -1356,9 +1420,10 @@ void frame_get_titlebar_dimensions(
 	*padd_coord += t_length;
 	/* configure right buttons */
 	*padd_coord -= br_sub;
-	for (i = 1 + ((NUMBER_OF_BUTTONS - 1) / 2) * 2; i >= 0; i -= 2)
+	for (i = NUMBER_OF_BUTTONS-1; i > -1; i--)
 	{
-		if (FW_W_BUTTON(fw, i) == None)
+		if ((revert_button && (i & 1)) || (!revert_button && !(i & 1)) ||
+		    FW_W_BUTTON(fw, i) == None)
 		{
 			continue;
 		}
@@ -1684,6 +1749,7 @@ frame_move_resize_args frame_create_move_resize_args(
 	 * if either the border uses a tiled pixmap background. */
 	mra->flags.had_handles = HAS_HANDLES(fw);
 	mra->flags.is_lazy_shading = frame_get_shading_laziness(fw, mra);
+	mra->trans_parts = border_get_transparent_decorations_part(fw);
 	if (mra->flags.is_lazy_shading)
 	{
 		SET_HAS_HANDLES(fw, 0);
@@ -1759,6 +1825,13 @@ void frame_free_move_resize_args(
 			(mra->w_with_focus != None) ? True : False, True,
 			CLEAR_ALL, &mra->current_g, &mra->next_g);
 	}
+	else if (mra->trans_parts != PART_NONE)
+	{
+		border_draw_decorations(
+			fw, mra->trans_parts,
+			(mra->w_with_focus != None) ? True : False, True,
+			CLEAR_ALL, &mra->current_g, &mra->next_g);
+	}
 	update_absolute_geometry(fw);
 	frame_reparent_hide_windows(Scr.NoFocusWin);
 	if (mra->w_with_focus != None)
@@ -1779,10 +1852,16 @@ void frame_free_move_resize_args(
 	frame_setup_shape(fw, mra->end_g.width, mra->end_g.height);
 	if (mra->flags.do_restore_gravity)
 	{
+		mra->grav.client_grav = fw->hints.win_gravity;
 		frame_set_decor_gravities(
 			fw, &mra->grav,
 			(mra->flags.do_set_bit_gravity) ? 2 : 0);
 	}
+	else
+	{
+		frame_restore_client_gravities(fw);
+	}
+
 	focus_grab_buttons_on_layer(fw->layer);
 	/* free the memory */
 	free(mr_args);
