@@ -19,21 +19,19 @@
 #include "config.h"
 
 #include <stdio.h>
-#include <X11/Intrinsic.h>
+
 #include "libs/fvwmlib.h"
-#include "libs/safemalloc.h"
-#include "libs/Flocale.h"
-#include <libs/Picture.h>
-#include <libs/PictureGraphics.h>
-#include "externs.h"
+#include "libs/Picture.h"
+#include "libs/PictureGraphics.h"
+#include "libs/Rectangles.h"
 #include "fvwm.h"
-#include "cursor.h"
-#include "functions.h"
+#include "externs.h"
+#include "execcontext.h"
 #include "misc.h"
 #include "screen.h"
 #include "menustyle.h"
+#include "menudim.h"
 #include "menuitem.h"
-#include "menus.h"
 #include "decorations.h"
 
 /* ---------------------------- local definitions --------------------------- */
@@ -53,6 +51,30 @@
 /* ---------------------------- exported variables (globals) ---------------- */
 
 /* ---------------------------- local functions ----------------------------- */
+void static
+clear_menu_item_background(
+	MenuPaintItemParameters *mpip, int x, int y, int w, int h)
+{
+	MenuStyle *ms = mpip->ms;
+
+	if (!ST_HAS_MENU_CSET(ms) &&
+	    ST_FACE(ms).type == GradientMenu &&
+	    (ST_FACE(ms).gradient_type == D_GRADIENT ||
+	     ST_FACE(ms).gradient_type == B_GRADIENT))
+	{
+		XEvent e;
+
+		e.xexpose.x = x;
+		e.xexpose.y = y;
+		e.xexpose.width = w;
+		e.xexpose.height = h;
+		mpip->cb_reset_bg(mpip->cb_mr, &e);
+	}
+	else
+	{
+		XClearArea(dpy, mpip->w, x, y, w, h, False);
+	}
+}
 
 /****************************************************************************
  *
@@ -190,19 +212,19 @@ MenuItem *menuitem_clone(MenuItem *mi)
 }
 
 /* Calculate the size of the various parts of the item.  The sizes are returned
- * through mips. */
+ * through mipst. */
 void menuitem_get_size(
-	MenuItem *mi, MenuItemPartSizes *mips, FlocaleFont *font,
+	MenuItem *mi, MenuItemPartSizesT *mipst, FlocaleFont *font,
 	Bool do_reverse_icon_order)
 {
 	int i;
 	int j;
 	unsigned short w;
 
-	memset(mips, 0, sizeof(MenuItemPartSizes));
+	memset(mipst, 0, sizeof(MenuItemPartSizesT));
 	if (MI_IS_POPUP(mi))
 	{
-		mips->triangle_width = MENU_TRIANGLE_WIDTH;
+		mipst->triangle_width = MENU_TRIANGLE_WIDTH;
 	}
 	else if (MI_IS_TITLE(mi) && !MI_HAS_PICTURE(mi))
 	{
@@ -230,9 +252,9 @@ void menuitem_get_size(
 				font, MI_LABEL(mi)[0], MI_LABEL_STRLEN(mi)[0]);
 			MI_LABEL_OFFSET(mi)[0] = w;
 			MI_IS_TITLE_CENTERED(mi) = True;
-			if (mips->title_width < w)
+			if (mipst->title_width < w)
 			{
-				mips->title_width = w;
+				mipst->title_width = w;
 			}
 			return;
 		}
@@ -246,15 +268,15 @@ void menuitem_get_size(
 			w = FlocaleTextWidth(
 				font, MI_LABEL(mi)[i], MI_LABEL_STRLEN(mi)[i]);
 			MI_LABEL_OFFSET(mi)[i] = w;
-			if (mips->label_width[i] < w)
+			if (mipst->label_width[i] < w)
 			{
-				mips->label_width[i] = w;
+				mipst->label_width[i] = w;
 			}
 		}
 	}
-	if (MI_PICTURE(mi) && mips->picture_width < MI_PICTURE(mi)->width)
+	if (MI_PICTURE(mi) && mipst->picture_width < MI_PICTURE(mi)->width)
 	{
-		mips->picture_width = MI_PICTURE(mi)->width;
+		mipst->picture_width = MI_PICTURE(mi)->width;
 	}
 	for (i = 0; i < MAX_MENU_ITEM_MINI_ICONS; i++)
 	{
@@ -265,7 +287,7 @@ void menuitem_get_size(
 			/* Reverse mini icon order for left submenu style. */
 			k = (do_reverse_icon_order == True) ?
 				MAX_MENU_ITEM_MINI_ICONS - 1 - i : i;
-			mips->icon_width[k] = MI_MINI_ICON(mi)[i]->width;
+			mipst->icon_width[k] = MI_MINI_ICON(mi)[i]->width;
 		}
 	}
 
@@ -296,16 +318,29 @@ void menuitem_paint(
 	int y;
 	int lit_x_start;
 	int lit_x_end;
+#if 0
 	GC ShadowGC;
 	GC ReliefGC;
 	GC on_gc;
 	GC off_gc;
-	int on_cs = -1, off_cs = -1;
+	GC text_gc;
+	int on_cs = -1;
+	int off_cs = -1;
+#else
+	gc_quad_t gcs;
+	gc_quad_t off_gcs;
+	int cs = -1;
+	int offff_cs;
+#endif
+	FvwmRenderAttributes fra;
 	/*Pixel fg, fgsh;*/
 	short relief_thickness = ST_RELIEF_THICKNESS(ms);
 	Bool is_item_selected;
-	Bool xft_redraw = False;
-	Bool alpha_redraw = False;
+	Bool item_cleared = False;
+	Bool xft_clear = False;
+	Bool empty_inter = False;
+	XRectangle b;
+	Region region = None;
 	int i;
 	int sx1;
 	int sx2;
@@ -349,14 +384,31 @@ void menuitem_paint(
 		}
 	}
 
-	ShadowGC = ST_MENU_SHADOW_GC(ms);
-	if (Pdepth<2)
+	offff_cs = ST_CSET_MENU(ms);
+	if (is_item_selected)
 	{
-		ReliefGC = ST_MENU_SHADOW_GC(ms);
+		cs = ST_CSET_ACTIVE(ms);
 	}
 	else
 	{
-		ReliefGC = ST_MENU_RELIEF_GC(ms);
+		cs = offff_cs;
+	}
+	/* Note: it's ok to pass a NULL label to is_function_allowed. */
+	if (!is_function_allowed(
+		    MI_FUNC_TYPE(mi), MI_LABEL(mi)[0], mpip->fw, True, False))
+	{
+		gcs = ST_MENU_STIPPLE_GCS(ms);
+		off_gcs = gcs;
+	}
+	else if (is_item_selected)
+	{
+		gcs = ST_MENU_ACTIVE_GCS(ms);
+		off_gcs = ST_MENU_INACTIVE_GCS(ms);
+	}
+	else
+	{
+		gcs = ST_MENU_INACTIVE_GCS(ms);
+		off_gcs = ST_MENU_INACTIVE_GCS(ms);
 	}
 
 	/***************************************************************
@@ -364,13 +416,14 @@ void menuitem_paint(
 	 ***************************************************************/
 	if (FftSupport && ST_PSTDFONT(ms)->fftf.fftfont != NULL)
 	{
-		xft_redraw = True;
+		xft_clear = True;
 	}
 
 	/* Hilight or clear the background. */
 	lit_x_start = -1;
 	lit_x_end = -1;
-	if (is_item_selected && ST_DO_HILIGHT(ms))
+	if (is_item_selected &&
+	    (ST_DO_HILIGHT_BACK(ms) || ST_DO_HILIGHT_FORE(ms)))
 	{
 		/* Hilight the background. */
 		if (MDIM_HILIGHT_WIDTH(*dim) - 2 * relief_thickness > 0)
@@ -380,18 +433,24 @@ void menuitem_paint(
 			lit_x_end = lit_x_start + MDIM_HILIGHT_WIDTH(*dim) -
 				2 * relief_thickness;
 			XChangeGC(dpy, Scr.ScratchGC1, Globalgcm, &Globalgcv);
-			XFillRectangle(
-				dpy, mpip->w, ST_MENU_ACTIVE_BACK_GC(ms),
-				lit_x_start, y_offset + relief_thickness,
-				lit_x_end - lit_x_start,
-				y_height - relief_thickness);
+			if (ST_DO_HILIGHT_BACK(ms))
+			{
+				XFillRectangle(
+					dpy, mpip->w, gcs.back_gc, lit_x_start,
+					y_offset + relief_thickness,
+					lit_x_end - lit_x_start,
+					y_height - relief_thickness);
+				item_cleared = True;
+			}
 		}
 	}
-	else if (xft_redraw ||
-		 (MI_WAS_DESELECTED(mi) &&
-		  (relief_thickness > 0 || ST_DO_HILIGHT(ms)) &&
+	else if ((MI_WAS_DESELECTED(mi) &&
+		  (relief_thickness > 0 ||
+		   ST_DO_HILIGHT_BACK(ms) || ST_DO_HILIGHT_FORE(ms)) &&
 		  (ST_FACE(ms).type != GradientMenu || ST_HAS_MENU_CSET(ms))))
 	{
+		/* we clear if xft_clear and !ST_HAS_MENU_CSET(ms) as the
+		 * non colorset code is too complicate ... olicha */
 		int d = 0;
 		if (MI_PREV_ITEM(mi) &&
 		    mpip->selected_item == MI_PREV_ITEM(mi))
@@ -400,44 +459,24 @@ void menuitem_paint(
 			d = relief_thickness;
 		}
 		/* Undo the hilighting. */
-		if (xft_redraw && !ST_HAS_MENU_CSET(ms) &&
-		    ST_FACE(ms).type == GradientMenu &&
-		    (ST_FACE(ms).gradient_type == D_GRADIENT ||
-		     ST_FACE(ms).gradient_type == B_GRADIENT))
-		{
-			XEvent e;
-
-			e.xexpose.x = MDIM_ITEM_X_OFFSET(*dim);
-			e.xexpose.y = y_offset + d;
-			e.xexpose.width = MDIM_ITEM_WIDTH(*dim);
-			e.xexpose.height = y_height + relief_thickness - d;
-			mpip->cb_reset_bg(mpip->cb_mr, &e);
-		}
-		else
-		{
-			XClearArea(
-				dpy, mpip->w, MDIM_ITEM_X_OFFSET(*dim),
-				y_offset + d, MDIM_ITEM_WIDTH(*dim),
-				y_height + relief_thickness - d,
-				0);
-		}
-	}
-	else
-	{
-		alpha_redraw = True;
+		clear_menu_item_background(
+			mpip, MDIM_ITEM_X_OFFSET(*dim), y_offset + d,
+			MDIM_ITEM_WIDTH(*dim), y_height + relief_thickness - d);
+		item_cleared = True;
 	}
 
 	MI_WAS_DESELECTED(mi) = False;
+	memset(&fra, 0, sizeof(fra));
+	fra.mask = 0;
+
 	/* Hilight 3D */
 	if (is_item_selected && relief_thickness > 0)
 	{
-		GC rgc = ReliefGC;
-		GC sgc = ShadowGC;
-		if (ST_HAS_ACTIVE_CSET(ms))
-		{
-			rgc = ST_MENU_ACTIVE_RELIEF_GC(ms);
-			sgc = ST_MENU_ACTIVE_SHADOW_GC(ms);
-		}
+		GC rgc;
+		GC sgc;
+
+		rgc = gcs.hilight_gc;
+		sgc = gcs.shadow_gc;
 		if (ST_IS_ITEM_RELIEF_REVERSED(ms))
 		{
 			GC tgc = rgc;
@@ -484,7 +523,7 @@ void menuitem_paint(
 		{
 			/* It's a separator. */
 			draw_separator(
-				mpip->w, ShadowGC, ReliefGC, sx1,
+				mpip->w, gcs.shadow_gc, gcs.hilight_gc, sx1,
 				y_offset + y_height - MENU_SEPARATOR_HEIGHT,
 				sx2);
 			/* Nothing else to do. */
@@ -506,7 +545,7 @@ void menuitem_paint(
 
 			/* It's a tear off bar. */
 			draw_tear_off_bar(
-				mpip->w, ShadowGC, ReliefGC, tx1,
+				mpip->w, gcs.shadow_gc, gcs.hilight_gc, tx1,
 				y_offset + relief_thickness +
 				MENU_TEAR_OFF_BAR_Y_OFFSET, tx2);
 		}
@@ -526,8 +565,8 @@ void menuitem_paint(
 			if (sx1 < sx2)
 			{
 				draw_separator(
-					mpip->w, ShadowGC, ReliefGC, sx1,
-					y, sx2);
+					mpip->w, gcs.shadow_gc, gcs.hilight_gc,
+					sx1, y, sx2);
 			}
 		}
 		/* Underline the title. */
@@ -540,8 +579,8 @@ void menuitem_paint(
 			{
 				y = y_offset + y_height - MENU_SEPARATOR_HEIGHT;
 				draw_separator(
-					mpip->w, ShadowGC, ReliefGC, sx1,
-					y, sx2);
+					mpip->w, gcs.shadow_gc, gcs.hilight_gc,
+					sx1, y, sx2);
 			}
 			break;
 		default:
@@ -550,56 +589,13 @@ void menuitem_paint(
 				y = y_offset + y_height - 1 -
 					i * MENU_UNDERLINE_HEIGHT;
 				XDrawLine(
-					dpy, mpip->w, ShadowGC, sx1, y,
+					dpy, mpip->w, gcs.shadow_gc, sx1, y,
 					sx2, y);
 			}
 			break;
 		}
 	}
 
-	/* Note: it's ok to pass a NULL label to is_function_allowed. */
-	if (is_function_allowed(
-		    MI_FUNC_TYPE(mi), MI_LABEL(mi)[0], mpip->fw, True, False))
-	{
-		on_gc = ST_MENU_ACTIVE_GC(ms);
-		if (ST_HAS_ACTIVE_CSET(ms))
-		{
-			on_cs = ST_CSET_ACTIVE(ms);
-		}
-		if (ST_DO_HILIGHT(ms) && !ST_HAS_ACTIVE_FORE(ms) &&
-		    !ST_HAS_ACTIVE_CSET(ms) && is_item_selected)
-		{
-			/* Use a lighter color for highlighted windows menu
-			 * items if the background is hilighted */
-			on_gc = ST_MENU_RELIEF_GC(ms);
-			on_cs = -1;
-		}
-
-		off_gc = ST_MENU_GC(ms);
-		if (ST_HAS_MENU_CSET(ms))
-		{
-			off_cs = ST_CSET_MENU(ms);
-		}
-	}
-	else
-	{
-		/* should be a shaded out word, not just re-colored. */
-		on_gc = ST_MENU_STIPPLE_GC(ms);
-		if (ST_HAS_GREYED_CSET(ms))
-		{
-			on_cs = ST_CSET_GREYED(ms);
-		}
-
-		off_gc = on_gc;
-		off_cs = on_cs;
-	}
-	if (!is_item_selected)
-	{
-		on_gc = off_gc;
-		on_cs = off_cs;
-	}
-
-
 	/***************************************************************
 	 * Draw the labels.
 	 ***************************************************************/
@@ -610,47 +606,110 @@ void menuitem_paint(
 	fws->win = mpip->w;
 	fws->y = text_y;
 	fws->flags.has_colorset = False;
+	b.y = text_y - ST_PSTDFONT(ms)->ascent;
+	b.height = ST_PSTDFONT(ms)->height + 1; /* ? */
+	if (!item_cleared && mpip->ev)
+	{
+		int u,v;
+		if (!frect_get_seg_intersection(
+			mpip->ev->xexpose.y,
+			mpip->ev->xexpose.height,
+			b.y, b.height,
+			&u, &v))
+		{
+			/* empty intersection */
+			empty_inter = True;
+		}
+		b.y = u;
+		b.height = v;
+	}
+
 	for (i = MAX_MENU_ITEM_LABELS; i-- > 0; )
 	{
-		if (MI_LABEL(mi)[i] && *(MI_LABEL(mi)[i]))
+		if (!empty_inter && MI_LABEL(mi)[i] && *(MI_LABEL(mi)[i]))
 		{
+			Bool draw_string = True;
+			int text_width;
+			int tmp_cs;
+
 			if (MI_LABEL_OFFSET(mi)[i] >= lit_x_start &&
 			    MI_LABEL_OFFSET(mi)[i] < lit_x_end)
 			{
 				/* label is in hilighted area */
-				fws->gc = on_gc;
-				if (on_cs >= 0)
-				{
-					fws->colorset = &Colorset[on_cs];
-					fws->flags.has_colorset = True;
-				}
+				fws->gc = gcs.fore_gc;
+				tmp_cs = cs;
 			}
 			else
 			{
 				/* label is in unhilighted area */
-				fws->gc = off_gc;
-				if (off_cs >= 0)
-				{
-					fws->colorset = &Colorset[off_cs];
-					fws->flags.has_colorset = True;
-				}
+				fws->gc = off_gcs.fore_gc;
+				tmp_cs = offff_cs;
+			}
+			if (tmp_cs >= 0)
+			{
+				fws->colorset = &Colorset[tmp_cs];
+				fws->flags.has_colorset = True;
 			}
 			fws->str = MI_LABEL(mi)[i];
-			fws->x = MI_LABEL_OFFSET(mi)[i];
-			FlocaleDrawString(dpy, ST_PSTDFONT(ms), fws, 0);
+			b.x = fws->x = MI_LABEL_OFFSET(mi)[i];
+			b.width = text_width = FlocaleTextWidth(
+				ST_PSTDFONT(ms), fws->str, strlen(fws->str));
+			if (!item_cleared && mpip->ev)
+			{
+				int s_x,s_w;
+				if (frect_get_seg_intersection(
+					mpip->ev->xexpose.x,
+					mpip->ev->xexpose.width,
+					fws->x, text_width,
+					&s_x, &s_w))
+				{
+					b.x = s_x;
+					b.width = s_w;
+					region = XCreateRegion();
+					XUnionRectWithRegion(&b, region, region);
+					fws->flags.has_clip_region = True;
+					fws->clip_region = region;
+					draw_string = True;
+					XSetRegion(dpy, fws->gc, region);
+				}
+				else
+				{
+					/* empty intersection */
+					draw_string = False;
+				}
+			}
+			if (draw_string)
+			{
+				if (!item_cleared && xft_clear)
+				{
+					clear_menu_item_background(
+						mpip,
+						b.x, b.y, b.width, b.height);
+				}
+				FlocaleDrawString(dpy, ST_PSTDFONT(ms), fws, 0);
+
+				/* hot key */
+				if (MI_HAS_HOTKEY(mi) && !MI_IS_TITLE(mi) &&
+				    (!MI_IS_HOTKEY_AUTOMATIC(mi) ||
+				     ST_USE_AUTOMATIC_HOTKEYS(ms)) &&
+				    MI_HOTKEY_COLUMN(mi) == i)
+				{
+					FlocaleDrawUnderline(
+						dpy, ST_PSTDFONT(ms),fws,
+						MI_HOTKEY_COFFSET(mi));
+				}
+			}
 		}
-		if (MI_HAS_HOTKEY(mi) && !MI_IS_TITLE(mi) &&
-		    (!MI_IS_HOTKEY_AUTOMATIC(mi) ||
-		     ST_USE_AUTOMATIC_HOTKEYS(ms)) &&
-		    MI_HOTKEY_COLUMN(mi) == i)
+		if (region)
 		{
-			FlocaleDrawUnderline(
-				dpy, ST_PSTDFONT(ms),fws,
-				MI_HOTKEY_COFFSET(mi));
+			XDestroyRegion(region);
+			region = None;
+			fws->flags.has_clip_region = False;
+			fws->clip_region = None;
+			XSetClipMask(dpy, fws->gc, None);
 		}
 	}
 
-
 	/***************************************************************
 	 * Draw the submenu triangle.
 	 ***************************************************************/
@@ -664,17 +723,17 @@ void menuitem_paint(
 		    is_item_selected)
 		{
 			/* triangle is in hilighted area */
-			tmp_gc = ReliefGC;
+			tmp_gc = gcs.hilight_gc;
 		}
 		else
 		{
 			/* triangle is in unhilighted area */
-			tmp_gc = ST_MENU_GC(ms);
+			tmp_gc = off_gcs.hilight_gc;
 		}
 		y = y_offset + (y_height - MENU_TRIANGLE_HEIGHT +
 				relief_thickness) / 2;
 		DrawTrianglePattern(
-			dpy, mpip->w, ReliefGC, ShadowGC, tmp_gc,
+			dpy, mpip->w, gcs.hilight_gc, gcs.shadow_gc, tmp_gc,
 			MDIM_TRIANGLE_X_OFFSET(*dim), y, MENU_TRIANGLE_WIDTH,
 			MENU_TRIANGLE_HEIGHT, 0,
 			(mpip->flags.is_left_triangle) ? 'l' : 'r',
@@ -688,17 +747,59 @@ void menuitem_paint(
 
 	if (MI_PICTURE(mi))
 	{
+		GC tmp_gc;
+		int tmp_cs;
+		Bool draw_picture = True;
+
 		x = menudim_middle_x_offset(mpip->dim) -
 			MI_PICTURE(mi)->width / 2;
 		y = y_offset + ((MI_IS_SELECTABLE(mi)) ? relief_thickness : 0);
-		if (alpha_redraw && MI_PICTURE(mi)->alpha != None)
+		if (x >= lit_x_start && x < lit_x_end)
 		{
-			XClearArea(dpy, mpip->w, x, y, MI_PICTURE(mi)->width,
-				   MI_PICTURE(mi)->height, False);
+			tmp_gc = gcs.fore_gc;
+			tmp_cs = cs;
+		}
+		else
+		{
+			tmp_gc = off_gcs.fore_gc;
+			tmp_cs = offff_cs;
+		}
+		fra.mask = FRAM_DEST_IS_A_WINDOW;
+		if (tmp_cs >= 0)
+		{
+			fra.mask |= FRAM_HAVE_ICON_CSET;
+			fra.colorset = &Colorset[tmp_cs];
+		}
+		b.x = x;
+		b.y = y;
+		b.width = MI_PICTURE(mi)->width;
+		b.height = MI_PICTURE(mi)->height;
+		if (!item_cleared && mpip->ev)
+		{
+			if (!frect_get_intersection(
+				mpip->ev->xexpose.x, mpip->ev->xexpose.y,
+				mpip->ev->xexpose.width,
+				mpip->ev->xexpose.height,
+				b.x, b.y, b.width, b.height, &b))
+			{
+				draw_picture = False;
+			}
+		}
+		if (draw_picture)
+		{
+			if (!item_cleared && (MI_PICTURE(mi)->alpha != None ||
+			     (tmp_cs >=0 &&
+			      Colorset[tmp_cs].icon_alpha_percent < 100)))
+			{
+				clear_menu_item_background(
+					mpip, b.x, b.y, b.width, b.height);
+			}
+			PGraphicsRenderPicture(
+				dpy, mpip->w, MI_PICTURE(mi), &fra,
+				mpip->w, tmp_gc, Scr.MonoGC, Scr.AlphaGC,
+				b.x - x, b.y - y, b.width, b.height,
+				b.x, b.y, b.width, b.height, False);
 		}
-		PGraphicsCopyFvwmPicture(
-			dpy, MI_PICTURE(mi), mpip->w, ReliefGC, 0, 0,
-			MI_PICTURE(mi)->width, MI_PICTURE(mi)->height, x, y);
 	}
 
 	/***************************************************************
@@ -708,6 +809,7 @@ void menuitem_paint(
 	for (i = 0; i < MAX_MENU_ITEM_MINI_ICONS; i++)
 	{
 		int k;
+		Bool draw_picture = True;
 
 		/* We need to reverse the mini icon order for left submenu
 		 * style. */
@@ -717,6 +819,7 @@ void menuitem_paint(
 		if (MI_MINI_ICON(mi)[i])
 		{
 			GC tmp_gc;
+			int tmp_cs;
 
 			if (MI_PICTURE(mi))
 			{
@@ -731,30 +834,60 @@ void menuitem_paint(
 					  relief_thickness : 0) -
 					 MI_MINI_ICON(mi)[i]->height) / 2;
 			}
-			if (alpha_redraw && MI_MINI_ICON(mi)[i]->alpha != None)
-			{
-				XClearArea(
-					dpy, mpip->w,
-					MDIM_ICON_X_OFFSET(*dim)[k], y,
-					MI_MINI_ICON(mi)[i]->width,
-					MI_MINI_ICON(mi)[i]->height, False);
-			}
 			if (MDIM_ICON_X_OFFSET(*dim)[k] >= lit_x_start &&
 			    MDIM_ICON_X_OFFSET(*dim)[k] < lit_x_end)
 			{
 				/* icon is in hilighted area */
-				tmp_gc = on_gc;
+				tmp_gc = gcs.fore_gc;
+				tmp_cs = cs;
 			}
 			else
 			{
 				/* icon is in unhilighted area */
-				tmp_gc = off_gc;
+				tmp_gc = off_gcs.fore_gc;
+				tmp_cs = offff_cs;
+			}
+			fra.mask = FRAM_DEST_IS_A_WINDOW;
+			if (tmp_cs >= 0)
+			{
+				fra.mask |= FRAM_HAVE_ICON_CSET;
+				fra.colorset = &Colorset[tmp_cs];
+			}
+			b.x = MDIM_ICON_X_OFFSET(*dim)[k];
+			b.y = y;
+			b.width = MI_MINI_ICON(mi)[i]->width;
+			b.height = MI_MINI_ICON(mi)[i]->height;
+			if (!item_cleared && mpip->ev)
+			{
+				if (!frect_get_intersection(
+					mpip->ev->xexpose.x,
+					mpip->ev->xexpose.y,
+					mpip->ev->xexpose.width,
+					mpip->ev->xexpose.height,
+					b.x, b.y, b.width, b.height, &b))
+				{
+					draw_picture = False;
+				}
+			}
+			if (draw_picture)
+			{
+				if (!item_cleared &&
+				    (MI_MINI_ICON(mi)[i]->alpha != None
+				    || (tmp_cs >=0 &&
+					Colorset[tmp_cs].icon_alpha_percent <
+					100)))
+				{
+					clear_menu_item_background(
+						mpip,
+						b.x, b.y, b.width, b.height);
+				}
+				PGraphicsRenderPicture(
+					dpy, mpip->w, MI_MINI_ICON(mi)[i], &fra,
+					mpip->w, tmp_gc, Scr.MonoGC, Scr.AlphaGC,
+					b.x - MDIM_ICON_X_OFFSET(*dim)[k],
+					b.y - y, b.width, b.height,
+					b.x, b.y, b.width, b.height, False);
 			}
-			PGraphicsCopyFvwmPicture(
-				dpy, MI_MINI_ICON(mi)[i], mpip->w, tmp_gc,
-				0, 0, MI_MINI_ICON(mi)[i]->width,
-				MI_MINI_ICON(mi)[i]->height,
-				MDIM_ICON_X_OFFSET(*dim)[k], y);
 		}
 	}
 
