@@ -39,9 +39,7 @@ window_list_item (window_list_entry *wle, window_list_options *opts)
   char *argv[4];
   char desk[10], cmd[200], geo[200];
 
-  /* support two ways for now: window context (new) and window id param (old) */
-  g_snprintf (cmd, sizeof (cmd), "WindowId %#lx %s %#lx",
-	      wle->w,
+  g_snprintf (cmd, sizeof (cmd), "%s %#lx",
 	      opts->function ? opts->function : "WindowListFunc",
 	      wle->w);
   g_snprintf(desk, sizeof (desk), "%d", wle->desk);
@@ -109,7 +107,7 @@ window_list (int argc, char **argv)
 	      if (opts->right_title)
 		{
 		  free (opts->right_title);
- 		  opts->right_title = NULL;
+		  opts->right_title = NULL;
 		}
 	      i++;
 	      if (strcmp (argv[i], "") != 0)
