@@ -120,11 +120,22 @@ static char s_g_bits[] = {0x01, 0x02, 0x04, 0x08};
 
 Window icon_win;	       /* icon window */
 
+static int MyVx, MyVy;		/* copy of Scr.Vx/y for drag logic */
+
 static char *GetBalloonLabel(const PagerWindow *pw,const char *fmt);
 extern void ExitPager(void);
 
 Pixmap default_pixmap = None;
 
+#ifdef DEBUG
+#define MYFPRINTF(X) \
+  fprintf X;\
+  fflush (stderr);
+#else
+#define MYFPRINTF(X)
+#endif
+
+
 /* discard certain events on a window */
 static void discard_events(long event_type, Window w, XEvent *last_ev)
 {
@@ -1097,6 +1108,9 @@ void DispatchEvent(XEvent *Event)
     }
     else if (Event->xbutton.button == 3)
     {
+      /* save initial virtual desk position for drag */
+      MyVx=Scr.Vx;
+      MyVy=Scr.Vy;
       for(i=0;i<ndesks;i++)
       {
 	if(Event->xany.window == Desks[i].w)
@@ -2125,8 +2139,8 @@ void MoveStickyWindows(void)
   t = Start;
   while(t!= NULL)
   {
-    if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY_ON_DESK(t)))||
-       (IS_STICKY_ON_DESK(t)))
+    if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY_ACROSS_DESKS(t)))||
+       (IS_STICKY_ACROSS_DESKS(t)))
     {
       if(t->desk != Scr.CurrentDesk)
       {
@@ -2157,7 +2171,7 @@ void Hilight(PagerWindow *t, int on)
     }
     else
     {
-      if(IS_STICKY_ON_DESK(t) || IS_STICKY_ON_PAGE(t))
+      if(IS_STICKY_ACROSS_DESKS(t) || IS_STICKY_ACROSS_PAGES(t))
       {
 	if(t->PagerView != None)
 	  XSetWindowBackgroundPixmap(dpy,t->PagerView,
@@ -2219,6 +2233,7 @@ void Scroll(int window_w, int window_h, int x, int y, int Desk,
 	static int last_sy = -999999;
 	int sx;
 	int sy;
+	int adjx,adjy;
 
 	/* Desk < 0 means we want to scroll an icon window */
 	if(Desk >= 0 && Desk + desk1 != Scr.CurrentDesk)
@@ -2227,9 +2242,12 @@ void Scroll(int window_w, int window_h, int x, int y, int Desk,
 	}
 
 	/* center around mouse */
-	x -= (desk_w / (1 + Scr.VxMax / Scr.MyDisplayWidth)) / 2;
-	y -= (desk_h / (1 + Scr.VyMax / Scr.MyDisplayHeight)) / 2;
+	adjx = (desk_w / (1 + Scr.VxMax / Scr.MyDisplayWidth));
+	adjy = (desk_h / (1 + Scr.VyMax / Scr.MyDisplayHeight));
+	x-=adjx/2;
+	y-=adjy/2;
 
+	/* adjust for pointer going out of range */
 	if(x < 0)
 	{
 		x = 0;
@@ -2238,47 +2256,51 @@ void Scroll(int window_w, int window_h, int x, int y, int Desk,
 	{
 		y = 0;
 	}
-
-	if(x > window_w)
+	
+	if(x > window_w-adjx)
 	{
-		x = window_w;
+		x = window_w-adjx;
 	}
-	if(y > window_h)
+	if(y > window_h-adjy)
 	{
-		y = window_h;
+		y = window_h-adjy;
 	}
 
 	sx = 0;
 	sy = 0;
 	if(window_w != 0)
 	{
-		sx = 100 * (x * Scr.VWidth / window_w - Scr.Vx) /
+		sx = 100 * (x * Scr.VWidth / window_w - MyVx) /
 			Scr.MyDisplayWidth;
 	}
 	if(window_h != 0)
 	{
-		sy = 100 * (y * Scr.VHeight / window_h - Scr.Vy) /
+		sy = 100 * (y * Scr.VHeight / window_h - MyVy) /
 			Scr.MyDisplayHeight;
 	}
-#ifdef DEBUG
-	fprintf(stderr,"[scroll]: %d %d %d %d %d %d\n", window_w, window_h, x,
-		y, sx, sy);
-#endif
+	MYFPRINTF((stderr,"[scroll]: %d %d %d %d %d %d\n", window_w, window_h, x,
+		y, sx, sy));
 	/* Make sure weExecuteCommandQueue(); don't get stuck a few pixels fromt
 	 * the top/left border. Since sx/sy are ints, values between 0 and 1 are
 	 * rounded down. */
-	if (sx == 0 && x == 0 && Scr.Vx != 0)
+	if (sx == 0 && x == 0 && MyVx != 0)
 	{
 		sx = -1;
 	}
-	if (sy == 0 && y == 0 && Scr.Vy != 0)
+	if (sy == 0 && y == 0 && MyVy != 0)
 	{
 		sy = -1;
 	}
+	if (sx==0&&sy==0) return;
 	if (Wait == 0 || last_sx != sx || last_sy != sy)
 	{
 		sprintf(command, "Scroll %d %d", sx, sy);
 		SendText(fd, command, 0);
+		/* Here we need to track the view offset on the desk. */
+		/* sx/y are are a percent of the screen to scroll. */
+		/* We don't use Scr.Vx/y since they lag the true position. */
+		MyVx+=Scr.MyDisplayWidth*sx/100;
+		MyVy+=Scr.MyDisplayHeight*sy/100;
 		Wait = 1;
 	}
 	if (Wait == 0)
@@ -2468,7 +2490,8 @@ void MoveWindow(XEvent *Event)
       x = Scr.VWidth - Scr.Vx - 1;
     if (y + Scr.Vy >= Scr.VHeight)
       y = Scr.VHeight - Scr.Vy - 1;
-    if((IS_ICONIFIED(t) && IS_ICON_STICKY_ON_DESK(t)) || (IS_STICKY_ON_DESK(t)))
+    if((IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_DESKS(t)) ||
+       (IS_STICKY_ACROSS_DESKS(t)))
     {
       NewDesk = Scr.CurrentDesk - desk1;
       if (x > Scr.MyDisplayWidth - 16)
@@ -2482,8 +2505,8 @@ void MoveWindow(XEvent *Event)
     }
     if(NewDesk + desk1 != t->desk)
     {
-      if((IS_ICONIFIED(t) && IS_ICON_STICKY_ON_DESK(t)) ||
-	 (IS_STICKY_ON_DESK(t)))
+      if((IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_DESKS(t)) ||
+	 (IS_STICKY_ACROSS_DESKS(t)))
       {
 	NewDesk = Scr.CurrentDesk - desk1;
 	if(t->desk != Scr.CurrentDesk)
@@ -2868,7 +2891,8 @@ void IconMoveWindow(XEvent *Event,PagerWindow *t)
       x = Scr.VWidth - Scr.Vx - 1;
     if (y + Scr.Vy >= Scr.VHeight)
       y = Scr.VHeight - Scr.Vy - 1;
-    if((IS_ICONIFIED(t) && IS_ICON_STICKY_ON_DESK(t)) || IS_STICKY_ON_DESK(t))
+    if((IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_DESKS(t)) ||
+       IS_STICKY_ACROSS_DESKS(t))
     {
       if (x > Scr.MyDisplayWidth - 16)
 	x = Scr.MyDisplayWidth - 16;
