@@ -60,6 +60,7 @@
 #define CMD_SELECT		"WindowListFunc $w"
 #define CMD_CLICK1		"Raise"
 #define CMD_CLICK3		"Lower"
+#define CMD_DEFAULT		"Nop"
 #endif
 
 /* ---------------------------- local macros -------------------------------- */
@@ -85,6 +86,7 @@ static GC hi_gc;
 static GC sh_gc;
 static GC miniIconGC;
 static Window rootWindow;
+static Window focusWindow;
 static FILE *errorFile;
 static XTextProperty windowName;
 static int deskNumber=0;
@@ -236,6 +238,7 @@ static void parse_cmd(char **ret_cmd, char *cmd)
 
 static Bool parse_options(void)
 {
+	int m;
 	char *tline;
 
 #if 0
@@ -245,7 +248,6 @@ static Bool parse_options(void)
 	mark_command = safestrdup(CMD_MARK);
 	select_command = safestrdup(CMD_SELECT);
 #endif
-
 	memset(ClickAction, 0, sizeof(ClickAction));
 	ClickAction[PROXY_ACTION_SELECT] = strdup(CMD_SELECT);
 	ClickAction[PROXY_ACTION_CLICK + 0] = strdup(CMD_CLICK1);
@@ -253,6 +255,10 @@ static Bool parse_options(void)
 	{
 		ClickAction[PROXY_ACTION_CLICK + 2] = strdup(CMD_CLICK3);
 	}
+	for(m=0;m<PROXY_ACTION_LAST;m++)
+		if(ClickAction[m]==NULL)
+			ClickAction[m] = strdup(CMD_DEFAULT);
+
 	InitGetConfigLine(fd, CatString3("*", MyName, 0));
 	for (GetConfigLine(fd, &tline); tline != NULL;
 		GetConfigLine(fd, &tline))
@@ -274,11 +280,14 @@ static Bool parse_options(void)
 			continue;
 		}
 
+		/* dump leading whitespace */
+		while(*tline==' ' || *tline=='\t')
+			tline++;
 #if STARTUP_DEBUG
 		strcat(startupText,resource);
-		strcat(startupText,"| ");
+		strcat(startupText," |");
 		strcat(startupText,tline);
-		strcat(startupText,"\n");
+		strcat(startupText,"|\n");
 #endif
 		if(!strncasecmp(resource,"Action",6))
 		{
@@ -651,6 +660,7 @@ static void OpenWindows(void)
 		OpenOneWindow(proxy);
 	}
 
+	selectProxy = NULL;
 	return;
 }
 
@@ -958,8 +968,10 @@ static void StartProxies(void)
 	{
 		return;
 	}
-	selectProxy=NULL;
+
 	enterProxy=NULL;
+	selectProxy=NULL;
+
 	send_command_to_fvwm(ClickAction[PROXY_ACTION_SHOW], None);
 	are_windows_shown = 1;
 	CloseWindows();
@@ -1015,7 +1027,7 @@ static void SelectProxy(void)
 	ProxyWindow *proxy;
 
 	HideProxies();
-	if(selectProxy && selectProxy->desk==deskNumber)
+	if(selectProxy)
 		send_command_to_fvwm(ClickAction[PROXY_ACTION_SELECT],
 				selectProxy->window);
 
@@ -1092,7 +1104,9 @@ static void ProcessMessage(FvwmPacket* packet)
 				free(proxy->name);
 			}
 			proxy->name = safestrdup((char*)&body[3]);
-			UpdateOneWindow(proxy);
+/*			UpdateOneWindow(proxy);
+*/
+			/*** window name not currently utilized anywhere */
 		}
 		break;
 	case M_ICON_NAME:
@@ -1104,11 +1118,14 @@ static void ProcessMessage(FvwmPacket* packet)
 				free(proxy->iconname);
 			}
 			proxy->iconname = safestrdup((char*)&body[3]);
-			UpdateOneWindow(proxy);
+/*			UpdateOneWindow(proxy);
+*/
+			DrawProxyBackground(proxy);
+			DrawProxy(proxy);
 		}
 		break;
 	case M_NEW_DESK:
-		if(deskNumber!=body[0] && are_windows_shown)
+		if(deskNumber!=body[0])
 		{
 			deskNumber=body[0];
 			if(are_windows_shown)
@@ -1135,6 +1152,12 @@ static void ProcessMessage(FvwmPacket* packet)
 			UpdateOneWindow(proxy);
 		}
 		break;
+	case M_FOCUS_CHANGE:
+	{
+		focusWindow=bh->w;
+/*		fprintf(errorFile,"M_FOCUS_CHANGE 0x%x\n",(int)focusWindow);
+*/
+	}
 	case M_STRING:
 	{
 		char *message=(char*)&body[3];
@@ -1150,6 +1173,11 @@ static void ProcessMessage(FvwmPacket* packet)
 			ProxyWindow *lastSelect=selectProxy;
 			ProxyWindow *newSelect=selectProxy;
 			ProxyWindow *first=prev? lastProxy: firstProxy;
+
+			/* auto-show if not already shown */
+			if (!are_windows_shown)
+				StartProxies();
+
 			if(startProxy && startProxy->desk==deskNumber)
 			{
 				newSelect=startProxy;
@@ -1182,13 +1210,19 @@ static void ProcessMessage(FvwmPacket* packet)
 		}
 		else if(StrEquals(token, "Circulate"))
 		{
-			Window w=(selectProxy)? selectProxy->window: None;
+			Window w;
+
+			/* auto-show if not already shown */
+			if (!are_windows_shown)
+				StartProxies();
+
+			w = (selectProxy) ? selectProxy->window : focusWindow;
 
 			strcpy(commandBuffer,next);
 			strcat(commandBuffer," SendToModule FvwmProxy Mark");
 
-			fprintf(errorFile, "0x%x Circulate \"%s\"\n",
-				(int)w,commandBuffer);
+			fprintf(errorFile, "0x%x:0x%x Circulate \"%s\"\n",
+				(int)selectProxy,(int)w,commandBuffer);
 			if(next)
 				SendFvwmPipe(fd,commandBuffer,w);
 		}
@@ -1200,13 +1234,20 @@ static void ProcessMessage(FvwmPacket* packet)
 		{
 			SelectProxy();
 		}
+		else if(StrEquals(token, "ShowToggle"))
+		{
+			if(are_windows_shown)
+				SelectProxy();
+			else
+				StartProxies();
+		}
 		else if(StrEquals(token, "Abort"))
 		{
 			AbortProxies(True);
 		}
 		else if(StrEquals(token, "Mark"))
 		{
-/*
+#if 0
 			Window w;
 
 			if (next == NULL)
@@ -1218,8 +1259,9 @@ static void ProcessMessage(FvwmPacket* packet)
 				proxy = NULL;
 			}
 			else
-*/
+#endif
 			{
+				focusWindow=bh->w;
 				proxy = FindProxy(bh->w);
 				fprintf(errorFile,
 					"Mark proxy 0x%x win 0x%x\n",
@@ -1315,7 +1357,7 @@ static void DispatchEvent(XEvent *pEvent)
 		proxy = FindProxy(window);
 		if(proxy)
 		{
-#if FALSE
+#if 0
 			/* TODO setup from Fvwm config */
 			if(pEvent->xbutton.button==Button1)
 				XRaiseWindow(dpy,proxy->window);
@@ -1449,7 +1491,7 @@ int main(int argc, char **argv)
 	fd_width = GetFdWidth();
 
 	SetMessageMask(
-		fd, M_STRING| M_CONFIGURE_WINDOW| M_ADD_WINDOW|
+		fd, M_STRING| M_CONFIGURE_WINDOW| M_ADD_WINDOW| M_FOCUS_CHANGE|
 		M_DESTROY_WINDOW| M_NEW_DESK| M_NEW_PAGE| M_ICON_NAME|
 		M_WINDOW_NAME| M_MINI_ICON| M_ICONIFY| M_DEICONIFY|
 		M_CONFIG_INFO| M_END_CONFIG_INFO);
@@ -1462,6 +1504,7 @@ int main(int argc, char **argv)
 	errorFile=fopen(logfilename,"a");
 
 	fprintf(errorFile,"FvwmProxy >>>>>>>>> STARTUP\n");
+	fflush(errorFile);
 #if STARTUP_DEBUG
 	fprintf(errorFile,"startup:\n%s-----\n",startupText);
 #endif
