@@ -38,31 +38,26 @@
 #include "libs/fvwmlib.h"
 #include "libs/Colorset.h"
 #include "libs/safemalloc.h"
+#include "libs/Flocale.h"
+#include "libs/Picture.h"
+#include "libs/PictureGraphics.h"
+#include "libs/Rectangles.h"
 
 #include "ButtonArray.h"
 #include "Mallocs.h"
 
-#ifdef I18N_MB
-#ifdef __STDC__
-#define XTextWidth(x,y,z) XmbTextEscapement(x ## set,y,z)
-#else
-#define XTextWidth(x,y,z) XmbTextEscapement(x/**/set,y,z)
-#endif
-#endif
-
-extern XFontStruct *ButtonFont, *SelButtonFont;
-#ifdef I18N_MB
-extern XFontSet ButtonFontset, SelButtonFontset;
-#endif
+extern FlocaleFont *FButtonFont, *FSelButtonFont;
 extern Display *dpy;
 extern Window win;
 extern GC shadow, hilite, graph, whitegc, blackgc, checkered, icongraph,
-          iconhilite, iconshadow, focusgraph, focushilite, focusshadow;
+	  iconhilite, iconshadow, focusgraph, focushilite, focusshadow;
 extern GC iconbackgraph;
 extern GC focusbackgraph;
+extern FlocaleWinString *FwinString;
 extern int button_width;
 extern int iconcolorset;
 extern int focuscolorset;
+extern int colorset;
 extern int NoBrightFocus;
 extern int ThreeDfvwm;
 extern char *FocusBackColor;
@@ -81,115 +76,152 @@ extern int NRows, RowHeight;
  *************************************************************************/
 
 /* Draws a 3D rectangle */
-void Draw3dRect(Window wn, int x, int y, int w, int h, int state,
-		Bool iconified)
+void Draw3dRect(
+	Window wn, int x, int y, int w, int h, XRectangle *bounding,
+	int state, Bool iconified)
 {
-  colorset_struct *cset = &Colorset[0];  /* initialize to avoid warning */
-  int d = 1;
+	colorset_t *cset = &Colorset[0];  /* initialize to avoid warning */
+	int d = 1;
+	XRectangle r,inter;
+	Bool draw;
 
-  if (ThreeDfvwm)
-    d = 2;
+	if (ThreeDfvwm)
+	{
+		d = 2;
+	}
+	if (bounding)
+	{
+		r.x = bounding->x;
+		r.y = bounding->y;
+		r.width = bounding->width;
+		r.height = bounding->height;
+	}
+	else
+	{
+		r.x = x;
+		r.y = y;
+		r.width = w;
+		r.height = h;
+	}
+	XClearArea (dpy, wn, r.x, r.y, r.width, r.height, False);
+	if (iconified)
+	{
+		draw = frect_get_intersection(
+			x + d, y + d, w - 3, h - 3,
+			r.x, r.y, r.width, r.height, &inter);
+		if (iconcolorset >= 0)
+		{
+			cset = &Colorset[iconcolorset];
+		}
+		if (iconcolorset >= 0 && (cset->pixmap || cset->shape_mask)
+		    && draw)
+		{
+			/* we have a colorset background */
+			SetClippedRectangleBackground(
+				dpy, win, x + d, y + d, w - 3, h - 3, &inter,
+				cset, Pdepth, icongraph);
+		}
+		else if (draw)
+		{
+			XFillRectangle (
+				dpy, wn, iconbackgraph,
+				inter.x, inter.y, inter.width, inter.height);
+		}
+		XDrawLine (dpy, wn, iconhilite, x, y, x+w-2, y);
+		XDrawLine (dpy, wn, iconhilite, x, y, x, y+h-2);
+		if (ThreeDfvwm)
+		{
+			XDrawLine (dpy, wn, iconhilite, x, y+1, x+w-2, y+1);
+			XDrawLine (dpy, wn, iconhilite, x+1, y, x+1, y+h-2);
+		}
+		XDrawLine (dpy, wn, iconshadow,  x+1, y+h-2, x+w-2, y+h-2);
+		XDrawLine (dpy, wn, iconshadow,  x+w-2, y+h-2, x+w-2, y+1);
+		XDrawLine (dpy, wn, blackgc, x, y+h-1, x+w-1, y+h-1);
+		XDrawLine (dpy, wn, blackgc, x+w-1, y+h-1, x+w-1, y);
+		return;
+	}
 
-  XClearArea (dpy, wn, x, y, w, h, False);
-  if (iconified)
-  {
-    if (iconcolorset >= 0)
-      cset = &Colorset[iconcolorset];
-    if (iconcolorset >= 0 && (cset->pixmap || cset->shape_mask))
-    {
-      /* we have a colorset background */
-      SetRectangleBackground(dpy, win, x + d, y + d, w - 3, h - 3, cset,
-			     Pdepth, icongraph);
-    }
-    else
-    {
-      XFillRectangle (dpy, wn, iconbackgraph, x + d, y + d, w - 3, h - 3);
-    }
-    XDrawLine (dpy, wn, iconhilite, x, y, x+w-2, y);
-    XDrawLine (dpy, wn, iconhilite, x, y, x, y+h-2);
-    if (ThreeDfvwm)
-    {
-      XDrawLine (dpy, wn, iconhilite, x, y+1, x+w-2, y+1);
-      XDrawLine (dpy, wn, iconhilite, x+1, y, x+1, y+h-2);
-    }
-    XDrawLine (dpy, wn, iconshadow,  x+1, y+h-2, x+w-2, y+h-2);
-    XDrawLine (dpy, wn, iconshadow,  x+w-2, y+h-2, x+w-2, y+1);
-    XDrawLine (dpy, wn, blackgc, x, y+h-1, x+w-1, y+h-1);
-    XDrawLine (dpy, wn, blackgc, x+w-1, y+h-1, x+w-1, y);
-    return;
-  }
+	switch (state)
+	{
+	case BUTTON_UP:
+		XDrawLine (dpy, wn, hilite, x, y, x+w-2, y);
+		XDrawLine (dpy, wn, hilite, x, y, x, y+h-2);
+		if (ThreeDfvwm)
+		{
+			XDrawLine (dpy, wn, hilite, x, y+1, x+w-2, y+1);
+			XDrawLine (dpy, wn, hilite, x+1, y, x+1, y+h-2);
+		}
+		XDrawLine (dpy, wn, shadow,  x+1, y+h-2, x+w-2, y+h-2);
+		XDrawLine (dpy, wn, shadow,  x+w-2, y+h-2, x+w-2, y+1);
+		XDrawLine (dpy, wn, blackgc, x, y+h-1, x+w-1, y+h-1);
+		XDrawLine (dpy, wn, blackgc, x+w-1, y+h-1, x+w-1, y);
+		break;
+	case BUTTON_BRIGHT:
+		draw = frect_get_intersection(
+				x + 2, y + 2, w - 4 + (2 - d), h - 4 + (2 - d),
+				r.x, r.y, r.width, r.height, &inter);
+		if (focuscolorset >= 0)
+			cset = &Colorset[focuscolorset];
+		if (focuscolorset >= 0 && (cset->pixmap || cset->shape_mask) &&
+		    draw)
+		{
+			/* we have a colorset background */
+			SetClippedRectangleBackground(
+				dpy, win, x + 2, y + 2, w - 4 + (2 - d),
+				h - 4 + (2 - d), &inter, cset, Pdepth,
+				focusgraph);
+		}
+		else if (draw)
+		{
+			XFillRectangle (
+				dpy, wn, focusbackgraph, inter.x, inter.y,
+				inter.width, inter.height);
+		}
+		if (!NoBrightFocus)
+			XFillRectangle (
+				dpy, wn, checkered, inter.x, inter.y,
+				inter.width, inter.height);
+		XDrawLine (dpy, wn, blackgc, x, y, x+w-2, y);
+		XDrawLine (dpy, wn, blackgc, x, y, x, y+h-2);
 
-  switch (state)
-  {
-  case BUTTON_UP:
-    XDrawLine (dpy, wn, hilite, x, y, x+w-2, y);
-    XDrawLine (dpy, wn, hilite, x, y, x, y+h-2);
-    if (ThreeDfvwm)
-    {
-      XDrawLine (dpy, wn, hilite, x, y+1, x+w-2, y+1);
-      XDrawLine (dpy, wn, hilite, x+1, y, x+1, y+h-2);
-    }
-    XDrawLine (dpy, wn, shadow,  x+1, y+h-2, x+w-2, y+h-2);
-    XDrawLine (dpy, wn, shadow,  x+w-2, y+h-2, x+w-2, y+1);
-    XDrawLine (dpy, wn, blackgc, x, y+h-1, x+w-1, y+h-1);
-    XDrawLine (dpy, wn, blackgc, x+w-1, y+h-1, x+w-1, y);
-    break;
-  case BUTTON_BRIGHT:
-    if (focuscolorset >= 0)
-      cset = &Colorset[focuscolorset];
-    if (focuscolorset >= 0 && (cset->pixmap || cset->shape_mask))
-    {
-      /* we have a colorset background */
-      SetRectangleBackground(dpy, win, x + 2, y + 2, w - 4 + (2 - d), 
-			     h - 4 + (2 - d), cset, Pdepth, focusgraph);
-    }
-    else
-    {
-      XFillRectangle (dpy, wn, focusbackgraph, x + 2, y + 2, 
-		      w - 4 + (2 - d), h - 4 + (2 - d));
-    }
-    if (!NoBrightFocus)
-      XFillRectangle (dpy, wn, checkered, x + 2, y + 2, 
-		      w - 4 + (2 - d), h - 4 + (2 - d));
-    XDrawLine (dpy, wn, blackgc, x, y, x+w-2, y);
-    XDrawLine (dpy, wn, blackgc, x, y, x, y+h-2);
+		XDrawLine (dpy, wn, focusshadow, x, y+1, x+w-2, y+1);
+		XDrawLine (dpy, wn, focusshadow, x+1, y, x+1, y+h-2);
+		if (ThreeDfvwm)
+		{
+			XDrawLine (
+				dpy, wn, focushilite,  x+1, y+h-2, x+w-2, y+h-2);
+			XDrawLine (
+				dpy, wn, focushilite,  x+w-2, y+h-2, x+w-2, y+1);
+		}
+		XDrawLine (dpy, wn, focushilite, x, y+h-1, x+w-1, y+h-1);
+		XDrawLine (dpy, wn, focushilite, x+w-1, y+h-1, x+w-1, y);
+		break;
+	case BUTTON_DOWN:
+		XDrawLine (dpy, wn, blackgc, x, y, x+w-2, y);
+		XDrawLine (dpy, wn, blackgc, x, y, x, y+h-2);
 
-    XDrawLine (dpy, wn, focusshadow, x, y+1, x+w-2, y+1);
-    XDrawLine (dpy, wn, focusshadow, x+1, y, x+1, y+h-2);
-    if (ThreeDfvwm)
-    {
-      XDrawLine (dpy, wn, focushilite,  x+1, y+h-2, x+w-2, y+h-2);
-      XDrawLine (dpy, wn, focushilite,  x+w-2, y+h-2, x+w-2, y+1);
-    }
-    XDrawLine (dpy, wn, focushilite, x, y+h-1, x+w-1, y+h-1);
-    XDrawLine (dpy, wn, focushilite, x+w-1, y+h-1, x+w-1, y);
-    break;
-  case BUTTON_DOWN:
-    XDrawLine (dpy, wn, blackgc, x, y, x+w-2, y);
-    XDrawLine (dpy, wn, blackgc, x, y, x, y+h-2);
-
-    XDrawLine (dpy, wn, shadow, x, y+1, x+w-2, y+1);
-    XDrawLine (dpy, wn, shadow, x+1, y, x+1, y+h-2);
-    if (ThreeDfvwm)
-    {
-      XDrawLine (dpy, wn, hilite,  x+1, y+h-2, x+w-2, y+h-2);
-      XDrawLine (dpy, wn, hilite,  x+w-2, y+h-2, x+w-2, y+1);
-    }
-    XDrawLine (dpy, wn, hilite, x, y+h-1, x+w-1, y+h-1);
-    XDrawLine (dpy, wn, hilite, x+w-1, y+h-1, x+w-1, y);
-    break;
-  }
+		XDrawLine (dpy, wn, shadow, x, y+1, x+w-2, y+1);
+		XDrawLine (dpy, wn, shadow, x+1, y, x+1, y+h-2);
+		if (ThreeDfvwm)
+		{
+			XDrawLine (dpy, wn, hilite,  x+1, y+h-2, x+w-2, y+h-2);
+			XDrawLine (dpy, wn, hilite,  x+w-2, y+h-2, x+w-2, y+1);
+		}
+		XDrawLine (dpy, wn, hilite, x, y+h-1, x+w-1, y+h-1);
+		XDrawLine (dpy, wn, hilite, x+w-1, y+h-1, x+w-1, y);
+		break;
+	}
 }
 
 
 /* -------------------------------------------------------------------------
    ButtonNew - Allocates and fills a new button structure
    ------------------------------------------------------------------------- */
-Button *ButtonNew(const char *title, Picture *p, int state, int count)
+Button *ButtonNew(const char *title, FvwmPicture *p, int state, int count)
 {
   Button *new;
 
-  if (title == NULL) 
+  if (title == NULL)
     return NULL;
   new = (Button *)safemalloc(sizeof(Button));
   new->title = safemalloc(strlen(title)+1);
@@ -197,6 +229,7 @@ Button *ButtonNew(const char *title, Picture *p, int state, int count)
   if (p != NULL) {
     new->p.picture = p->picture;
     new->p.mask    = p->mask;
+    new->p.alpha   = p->alpha;
     new->p.width   = p->width;
     new->p.height  = p->height;
     new->p.depth   = p->depth;
@@ -216,130 +249,175 @@ Button *ButtonNew(const char *title, Picture *p, int state, int count)
 /* -------------------------------------------------------------------------
    ButtonDraw - Draws the specified button
    ------------------------------------------------------------------------- */
-void ButtonDraw(Button *button, int x, int y, int w, int h)
+void ButtonDraw(Button *button, int x, int y, int w, int h, XEvent *evp)
 {
-  char *t3p = "...";
-  int state, x3p, newx;
-  int search_len;
-  XFontStruct *font;
-#ifdef I18N_MB
-  XFontSet fontset;
-#endif
-  XGCValues gcv;
-  unsigned long gcm;
-  GC *drawgc;
+	char *t3p = "...\0";
+	int state, x3p, newx;
+	int search_len;
+	FlocaleFont *Ffont;
+	XGCValues gcv;
+	unsigned long gcm;
+	GC *drawgc;
+	int cs;
+	XRectangle rect,inter;
+	Region t_region;
 
-  if (button == NULL)
-    return;
-  button->needsupdate = 0;
-  state = button->state;
-  Draw3dRect(win, x, y, w, h, state, !!(button->iconified));
-  if (button->iconified)
-    drawgc = &icongraph;
-  else if (state == BUTTON_BRIGHT)
-    drawgc = &focusgraph;
-  else
-    drawgc = &graph;
+	if (button == NULL)
+	{
+		return;
+	}
+	if (evp)
+	{
+		if (!frect_get_intersection(
+			x, y, w, h,
+			evp->xexpose.x, evp->xexpose.y,
+			evp->xexpose.width, evp->xexpose.height,
+			&rect))
+		{
+			return;
+		}
+	}
+	else
+	{
+		rect.x = x;
+		rect.y = y;
+		rect.width = w;
+		rect.height = h;
+	}
+	button->needsupdate = 0;
+	state = button->state;
+	Draw3dRect(
+		win, x, y, w, h, &rect, state, !!(button->iconified));
+	if (button->iconified)
+	{
+		drawgc = &icongraph;
+		cs = iconcolorset;
+	}
+	else if (state == BUTTON_BRIGHT)
+	{
+		drawgc = &focusgraph;
+		cs = focuscolorset;
+	}
+	else
+	{
+		drawgc = &graph;
+		cs = colorset;
+	}
 
-  if (state != BUTTON_UP) { x++; y++; }
+	if (state != BUTTON_UP) { x++; y++; }
 
-  if (state == BUTTON_BRIGHT || button == StartButton)
-#ifdef I18N_MB
-  {
-    font = SelButtonFont;
-    fontset = SelButtonFontset;
-  }
-#else
-    font = SelButtonFont;
-#endif
-  else
-#ifdef I18N_MB
-  {
-    font = ButtonFont;
-    fontset = ButtonFontset;
-  }
-#else
-    font = ButtonFont;
-#endif
+	if (state == BUTTON_BRIGHT || button == StartButton)
+	{
+		Ffont = FSelButtonFont;
+	}
+	else
+	{
+		Ffont = FButtonFont;
+	}
 
-  gcm = GCFont;
-  gcv.font = font->fid;
-  XChangeGC(dpy, *drawgc, gcm, &gcv);
+	if (Ffont->font != NULL)
+	{
+		gcm = GCFont;
+		gcv.font = Ffont->font->fid;
+		XChangeGC(dpy, *drawgc, gcm, &gcv);
+	}
 
-  newx = 4;
+	newx = 4;
+	w3p = FlocaleTextWidth(Ffont, t3p, 3);
 
-  w3p = XTextWidth(font, t3p, 3);
+	if (button->p.picture != 0)
+	{
+		/* clip pixmap to fit inside button */
+		int pheight = min(button->p.height, h-2);
+		int offset = (button->p.height > h) ?
+			0 : ((h - button->p.height) >> 1);
+		int pwidth = min(button->p.width, w-5);
+		FvwmRenderAttributes fra;
 
-  if (button->p.picture != 0)
-  {
-    /* clip pixmap to fit inside button */
-    int pheight = min(button->p.height, h-2);
-    int offset = (button->p.height > h) ? 0 : ((h - button->p.height) >> 1);
-    int pwidth = min(button->p.width, w-5);
-    gcm = GCClipMask | GCClipXOrigin | GCClipYOrigin;
-    gcv.clip_mask = button->p.mask;
-    gcv.clip_x_origin = x + 3;
-    gcv.clip_y_origin = y + offset;
-    XChangeGC(dpy, hilite, gcm, &gcv);
-    XCopyArea(dpy, button->p.picture, win, hilite, 0, 0,
-                   pwidth, pheight,
-                   gcv.clip_x_origin, gcv.clip_y_origin);
-    gcm = GCClipMask;
-    gcv.clip_mask = None;
-    XChangeGC(dpy, hilite, gcm, &gcv);
+		fra.mask = FRAM_DEST_IS_A_WINDOW;
+		if (cs >= 0)
+		{
+			fra.mask |= FRAM_HAVE_ICON_CSET;
+			fra.colorset = &Colorset[cs];
+		}
+		if (frect_get_intersection(
+			rect.x, rect.y, rect.width, rect.height,
+			x+3, y+offset, pwidth, pheight, &inter))
+		{
+			PGraphicsRenderPicture(
+				dpy, win, &(button->p), &fra, win,
+				*drawgc, None, None,
+				(inter.x > (x+3))? inter.x - (x+3):0,
+				(inter.y > (y+offset))? inter.y - (y+offset):0,
+				inter.width, inter.height,
+				inter.x /*x+3*/, inter.y /*y+offset*/,
+				inter.width, inter.height, False);
+		}
+		newx += pwidth+2;
+	}
 
-    newx += pwidth+2;
-  }
+	if (button->title == NULL)
+	{
+		return;
+	}
+	
+	t_region = XCreateRegion();
+	XUnionRectWithRegion (&rect, t_region, t_region);
+	/* see if we have the place for "...", if not for "..", if not for "."
+	 * if not return */
+	if ((newx + w3p + 2) >= w)
+	{
+		t3p = "..\0";
+		w3p = FlocaleTextWidth(Ffont, t3p, 2);
+		if ((newx + w3p + 2) >= w)
+		{
+			t3p = ".\0";
+			w3p = FlocaleTextWidth(Ffont, t3p, 1);
+			if ((newx + w3p + 2) >= w)
+				return;
+		}
+	}
 
-  if (button->title == NULL)
-    return;
+	search_len = strlen(button->title);
+	FwinString->win = win;
+	FwinString->y = y + Ffont->ascent + (RowHeight - Ffont->height)/2;
+	FwinString->gc = *drawgc;
+	FwinString->flags.has_colorset = False;
+	FwinString->flags.has_clip_region = True;
+	FwinString->clip_region = t_region;
+	if (cs >= 0)
+	{
+		FwinString->colorset = &Colorset[cs];
+		FwinString->flags.has_colorset = True;
+	}
+	button->truncate = False;
 
-  /* see if we have the place for "...", if not for "..", if not for "."
-   * if not return */
-  if ((newx + w3p + 2) >= w)
-  {
-    t3p = "..\0";
-    w3p = XTextWidth(font, t3p, 2);
-    if ((newx + w3p + 2) >= w)
-    {
-      t3p = ".\0";
-      w3p = XTextWidth(font, t3p, 1);
-      if ((newx + w3p + 2) >= w)
-	return;
-    }
-  }
+	if (FlocaleTextWidth(Ffont, button->title, search_len) > w-newx-3)
+	{
+		x3p = 0;
+		while (search_len >= 0
+		       && ((x3p = newx + FlocaleTextWidth(
+					      Ffont, button->title, search_len))
+			   > w-w3p-3))
+		{
+			search_len--;
+		}
+		FwinString->str = t3p;
+		FwinString->x = x + x3p;
+		FlocaleDrawString(dpy, Ffont, FwinString, 0);
+		button->truncate = True;
+	}
 
-  search_len = strlen(button->title);
-
-  button->truncate = False;
-  if (XTextWidth(font, button->title, search_len) > w-newx-3) {
-
-    x3p = 0;
-    while (search_len >= 0
-	   && ((x3p = newx + XTextWidth(font, button->title, search_len))
-	       > w-w3p-3))
-      search_len--;
-
-    /* It seems a little bogus that we don't see if the "..." _itself_
-       will fit on the button; what if it won't?  Oh well.  */
-#ifdef I18N_MB
-    XmbDrawString(dpy, win, fontset,
-#else
-    XDrawString(dpy, win,
-#endif
-		*drawgc, x + x3p, y+ButtonFont->ascent+4, t3p, 3);
-    button->truncate = True;
-  }
-
-  /* Only print as much of the title as will fit.  */
-  if (search_len)
-#ifdef I18N_MB
-    XmbDrawString(dpy, win, fontset,
-#else
-    XDrawString(dpy, win,
-#endif
-		*drawgc, x+newx, y+font->ascent+4,
-		button->title, search_len);
+	/* Only print as much of the title as will fit.  */
+	if (search_len)
+	{
+		FwinString->str = button->title;
+		FwinString->x = x + newx;
+		FwinString->len = search_len;
+		FlocaleDrawString(dpy, Ffont, FwinString, FWS_HAVE_LENGTH);
+	}
+	FwinString->flags.has_clip_region = False;
+	XDestroyRegion(t_region);
 }
 
 
@@ -431,8 +509,8 @@ void UpdateArray(ButtonArray *array,int x,int y,int w, int h, int tw)
 /* -------------------------------------------------------------------------
    AddButton - Allocate space for and add the button to the list
    ------------------------------------------------------------------------- */
-void AddButton(ButtonArray *array, const char *title, Picture *p, int state,
-               int count, int iconified)
+void AddButton(ButtonArray *array, const char *title, FvwmPicture *p, int state,
+	       int count, int iconified)
 {
   Button *new, *temp;
 
@@ -456,7 +534,7 @@ void AddButton(ButtonArray *array, const char *title, Picture *p, int state,
 
 /* -------------------------------------------------------------------------
    ArrangeButtonArray - Rearrange the button size (called from AddButton,
-                          RemoveButton, AdjustWindow)
+			  RemoveButton, AdjustWindow)
    ------------------------------------------------------------------------- */
 
 void ArrangeButtonArray (ButtonArray *array)
@@ -501,7 +579,7 @@ int UpdateButton(ButtonArray *array, int butnum, const char *title, int state)
 /* -------------------------------------------------------------------------
    UpdateButtonPicture - Change the picture of a button
    ------------------------------------------------------------------------- */
-int UpdateButtonPicture(ButtonArray *array, int butnum, Picture *p)
+int UpdateButtonPicture(ButtonArray *array, int butnum, FvwmPicture *p)
 {
   Button *temp;
 
@@ -513,6 +591,7 @@ int UpdateButtonPicture(ButtonArray *array, int butnum, Picture *p)
   if (temp->p.picture != p->picture || temp->p.mask != p->mask) {
     temp->p.picture = p->picture;
     temp->p.mask    = p->mask;
+    temp->p.alpha   = p->alpha;
     temp->p.width   = p->width;
     temp->p.height  = p->height;
     temp->p.depth   = p->depth;
@@ -592,21 +671,37 @@ void FreeAllButtons(ButtonArray *array)
 /* ------------------------------------------------------------------------
    DrawButtonArray - Draw the whole array (all=1), or only those that need.
    ------------------------------------------------------------------------ */
-void DrawButtonArray(ButtonArray *array, int all)
+void DrawButtonArray(ButtonArray *array, int all, XEvent *evp)
 {
-  Button *temp;
-  int x, y, n;
+	Button *temp;
+	int x, y, n;
+	static Bool exposed = False;
 
-  x = 0;
-  y = array->y;
-  n = 1;
-  for(temp=array->head; temp!=NULL; temp=temp->next) {
-    if ((x + array->tw > array->w) && (n < NRows))
-      { x = 0; y += RowHeight+2; ++n; }
-    if (temp->needsupdate || all)
-      ButtonDraw(temp, x + array->x, y, array->tw-3, array->h);
-    x += array->tw;
-  }
+	if (!exposed && evp)
+	{
+		exposed = True;
+	}
+	if (!exposed)
+	{
+		return;
+	}
+	x = 0;
+	y = array->y;
+	n = 1;
+	for(temp=array->head; temp!=NULL; temp=temp->next)
+	{
+		if ((x + array->tw > array->w) && (n < NRows))
+		{
+			x = 0;
+			y += RowHeight+2;
+			++n;
+		}
+		if (temp->needsupdate || all)
+			ButtonDraw(
+				temp, x + array->x, y, array->tw-3, array->h,
+				(temp->needsupdate)? NULL:evp);
+		x += array->tw;
+	}
 }
 
 /* -------------------------------------------------------------------------
@@ -628,6 +723,32 @@ void RadioButton(ButtonArray *array, int butnum, int state)
     }
   }
 }
+/* -------------------------------------------------------------------------
+   
+   ------------------------------------------------------------------------- */
+Bool CheckRootTransparentButtons(ButtonArray *array)
+{
+	Button *button;
+	Bool r = 0;
+
+	if (!CSET_IS_TRANSPARENT_ROOT(iconcolorset) &&
+	    !CSET_IS_TRANSPARENT_ROOT(focuscolorset))
+	{
+		return r;
+	}
+	for(button=array->head; button!=NULL; button=button->next)
+	{
+		if ((button->iconified &&
+		     CSET_IS_TRANSPARENT_ROOT(iconcolorset)) ||
+		    (button->state == BUTTON_BRIGHT &&
+		     CSET_IS_TRANSPARENT_ROOT(focuscolorset)))
+		{
+			r = True;
+			button->needsupdate = 1;
+		}
+	}
+	return r;
+}
 
 /* -------------------------------------------------------------------------
    WhichButton - Based on x,y which button was pressed
@@ -655,7 +776,7 @@ int LocateButton(ButtonArray *array, int xp,  int yp, int *xb, int *yb,
     if((x + array->tw > array->w) && (n < NRows))
       { x = 0; y += RowHeight+2; ++n; }
     if( xp >= x+array->x && xp <= x+array->x+array->tw-3 &&
-        yp >= y && yp <= y+array->h) break;
+	yp >= y && yp <= y+array->h) break;
     x += array->tw;
   }
 
@@ -676,22 +797,34 @@ int LocateButton(ButtonArray *array, int xp,  int yp, int *xb, int *yb,
 /* -------------------------------------------------------------------------
     ButtonCoordinates - Compute the coordinates of a button (animation)
    ------------------------------------------------------------------------- */
-extern int StartButtonWidth;
+extern int  StartAndLaunchButtonsWidth;
 void ButtonCoordinates(ButtonArray *array, int numbut, int *xc, int *yc)
 {
-  Button *temp;
-  int x = 0;
-  int y = 0;
-  int r = 0;
+	Button *temp;
+	int x = 0;
+	int y = 0;
+	int r = 0;
 
-  for(temp=array->head; temp->count != numbut; temp=temp->next) {
-    if((x + 2*array->tw > array->w) && (r < NRows))
-      { x = 0; y += RowHeight+2; ++r; }
-    else
-     x += array->tw;
-  }
+	for(temp=array->head; temp->count != numbut; temp=temp->next)
+	{
+		if((x + 2*array->tw > array->w) && (r < NRows))
+		{
+			x = 0;
+			y += RowHeight+2;
+			++r;
+		}
+		else
+		{
+			x += array->tw;
+		}
+	}
 
-  *xc = x+StartButtonWidth+3;
-  *yc = y;
+	*xc = x+ StartAndLaunchButtonsWidth+3;
+	*yc = y;
 }
 
+void ButtonDimensions(ButtonArray *array, int *width, int *height)
+{
+	*width = array->tw;
+	*height = RowHeight+2;
+}
