@@ -904,13 +904,23 @@ void redraw_buttons()
 
   for (item=windows.head; item; item=item->next)
   {
-    if ((DeskNumber == item->Desk || IS_STICKY_ON_DESK(item) ||
-	 (IS_ICONIFIED(item) && IS_ICON_STICKY_ON_DESK(item))) &&
-	(!DO_SKIP_WINDOW_LIST(item) || !UseSkipList))
+    if ((DeskNumber != item->Desk && !IS_STICKY_ACROSS_DESKS(item) &&
+	 (!IS_ICONIFIED(item) || !IS_ICON_STICKY_ACROSS_DESKS(item))))
     {
-      AddButton(&buttons, item->name, &(item->p), BUTTON_UP, item->count,
-		IS_ICONIFIED(item));
+	    continue;
     }
+    if (DO_SKIP_WINDOW_LIST(item) && UseSkipList)
+    {
+	    continue;
+    }
+    if (PageOnly &&
+	!fvwmrect_do_rectangles_intersect(&item->win_g, &global_scr_g))
+    {
+	    continue;
+    }
+    AddButton(
+	    &buttons, item->name, &(item->p), BUTTON_UP, item->count,
+	    IS_ICONIFIED(item));
   }
 
   RedrawWindow(1, NULL);
@@ -1910,13 +1920,13 @@ static void CreateOrUpdateGCs(void)
    if (iconbackgraph)
      XChangeGC(dpy,icongraph,gcmask,&gcval);
    else
-     icongraph = fvwmlib_XCreateGC(dpy,Root,gcmask,&gcval);
+     icongraph = fvwmlib_XCreateGC(dpy,win,gcmask,&gcval);
 
    gcval.foreground = piconback;
    if (iconbackgraph)
      XChangeGC(dpy,iconbackgraph,gcmask,&gcval);
    else
-     iconbackgraph = fvwmlib_XCreateGC(dpy,Root,gcmask,&gcval);
+     iconbackgraph = fvwmlib_XCreateGC(dpy,win,gcmask,&gcval);
 
    gcval.foreground = piconshadow;
    if (iconshadow)
@@ -1935,13 +1945,13 @@ static void CreateOrUpdateGCs(void)
    if (focusbackgraph)
      XChangeGC(dpy,focusgraph,gcmask,&gcval);
    else
-     focusgraph = fvwmlib_XCreateGC(dpy,Root,gcmask,&gcval);
+     focusgraph = fvwmlib_XCreateGC(dpy,win,gcmask,&gcval);
 
    gcval.foreground = pfocusback;
       if (focusbackgraph)
      XChangeGC(dpy,focusbackgraph,gcmask,&gcval);
    else
-     focusbackgraph = fvwmlib_XCreateGC(dpy,Root,gcmask,&gcval);
+     focusbackgraph = fvwmlib_XCreateGC(dpy,win,gcmask,&gcval);
 
    gcval.foreground = pfocusshadow;
    if (focusshadow)
